import * as vue from 'vue';
import { ComponentPropsOptions, ExtractPropTypes, JSXComponent, PropType } from 'vue';

interface FilterPropsOptions<PropsOptions extends Readonly<ComponentPropsOptions>, Props = ExtractPropTypes<PropsOptions>> {
    filterProps<T extends Partial<Props>, U extends Exclude<keyof Props, Exclude<keyof Props, keyof T>>>(props: T): [yes: Partial<Pick<T, U>>, no: Omit<T, U>];
}

type SelectItemKey = boolean | string | (string | number)[] | ((item: Record<string, any>, fallback?: any) => any);

interface InternalItem<T = any> {
    title: string;
    value: any;
    props: {
        [key: string]: any;
        title: string;
        value: any;
    };
    children?: InternalItem<T>[];
    raw: T;
}

/**
 * - match without highlight
 * - single match (index), length already known
 * - single match (start, end)
 * - multiple matches (start, end), probably shouldn't overlap
 */
type FilterMatch = boolean | number | [number, number] | [number, number][];
type FilterFunction = (value: string, query: string, item?: any) => FilterMatch;
type FilterKeyFunctions = Record<string, FilterFunction>;
type FilterKeys = string | string[];
type FilterMode = 'some' | 'every' | 'union' | 'intersection';

type DataTableCompareFunction<T = any> = (a: T, b: T) => number;
type DataTableHeader = {
    key: string;
    value?: SelectItemKey;
    title: string;
    colspan?: number;
    rowspan?: number;
    fixed?: boolean;
    align?: 'start' | 'end';
    width?: number;
    minWidth?: string;
    maxWidth?: string;
    sortable?: boolean;
    sort?: DataTableCompareFunction;
};
type InternalDataTableHeader = DataTableHeader & {
    sortable: boolean;
    fixedOffset?: number;
    lastFixed?: boolean;
};
type DataTableItem = InternalItem & {
    type: 'item';
    columns: Record<string, unknown>;
};
type GroupHeaderItem = {
    type: 'group-header';
    id: string;
    key: string;
    value: string;
    depth: number;
    items: (GroupHeaderItem | DataTableItem)[];
};
type InternalDataTableItem = DataTableItem | GroupHeaderItem;

type SortItem = {
    key: string;
    order?: boolean | 'asc' | 'desc';
};

type IconValue = string | (string | [path: string, opacity: number])[] | JSXComponent;
declare const IconValue: PropType<IconValue>;

type Density = null | 'default' | 'comfortable' | 'compact';

type GroupHeaderSlot = {
    index: number;
    item: GroupHeaderItem;
    columns: InternalDataTableHeader[];
    isExpanded: (item: DataTableItem) => boolean;
    toggleExpand: (item: DataTableItem) => void;
    isSelected: (items: DataTableItem[]) => boolean;
    toggleSelect: (item: DataTableItem) => void;
    toggleGroup: (group: GroupHeaderItem) => void;
    isGroupOpen: (group: GroupHeaderItem) => boolean;
};
type ItemSlot = {
    index: number;
    item: DataTableItem;
    columns: InternalDataTableHeader[];
    isExpanded: (item: DataTableItem) => boolean;
    toggleExpand: (item: DataTableItem) => void;
    isSelected: (items: DataTableItem[]) => boolean;
    toggleSelect: (item: DataTableItem) => void;
};
declare const VDataTableRows: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            noDataText: string;
            loadingText: string;
            items: InternalDataTableItem[];
            hideNoData: boolean;
        }> & Omit<{
            noDataText: string;
            loadingText: string;
            items: InternalDataTableItem[];
            hideNoData: boolean;
        } & {
            loading?: string | boolean | undefined;
            rowHeight?: number | undefined;
            'onClick:row'?: ((e: Event, value: {
                item: DataTableItem;
            }) => void) | undefined;
        } & {
            $children?: vue.VNodeChild | (() => vue.VNodeChild) | {
                [x: `item.${string}`]: ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
                default?: (() => vue.VNodeChild) | undefined;
                item?: ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
                loading?: (() => vue.VNodeChild) | undefined;
                'group-header'?: ((args_0: GroupHeaderSlot) => vue.VNodeChild) | undefined;
                'no-data'?: (() => vue.VNodeChild) | undefined;
                'expanded-row'?: ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
                'item.data-table-select'?: ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
                'item.data-table-expand'?: ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
            };
            'v-slots'?: {
                [x: `item.${string}`]: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
                default?: false | (() => vue.VNodeChild) | undefined;
                item?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
                loading?: false | (() => vue.VNodeChild) | undefined;
                'group-header'?: false | ((args_0: GroupHeaderSlot) => vue.VNodeChild) | undefined;
                'no-data'?: false | (() => vue.VNodeChild) | undefined;
                'expanded-row'?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
                'item.data-table-select'?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
                'item.data-table-expand'?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
            } | undefined;
        } & {
            [x: `v-slot:item.${string}`]: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
            "v-slot:default"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:item"?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
            "v-slot:loading"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:group-header"?: false | ((args_0: GroupHeaderSlot) => vue.VNodeChild) | undefined;
            "v-slot:no-data"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:expanded-row"?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
            "v-slot:item.data-table-select"?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
            "v-slot:item.data-table-expand"?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
        } & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "noDataText" | "loadingText" | "items" | "hideNoData">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: (event: string, ...args: any[]) => void;
        $el: any;
        $options: vue.ComponentOptionsBase<{
            noDataText: string;
            loadingText: string;
            items: InternalDataTableItem[];
            hideNoData: boolean;
        } & {
            loading?: string | boolean | undefined;
            rowHeight?: number | undefined;
            'onClick:row'?: ((e: Event, value: {
                item: DataTableItem;
            }) => void) | undefined;
        } & {
            $children?: vue.VNodeChild | (() => vue.VNodeChild) | {
                [x: `item.${string}`]: ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
                default?: (() => vue.VNodeChild) | undefined;
                item?: ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
                loading?: (() => vue.VNodeChild) | undefined;
                'group-header'?: ((args_0: GroupHeaderSlot) => vue.VNodeChild) | undefined;
                'no-data'?: (() => vue.VNodeChild) | undefined;
                'expanded-row'?: ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
                'item.data-table-select'?: ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
                'item.data-table-expand'?: ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
            };
            'v-slots'?: {
                [x: `item.${string}`]: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
                default?: false | (() => vue.VNodeChild) | undefined;
                item?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
                loading?: false | (() => vue.VNodeChild) | undefined;
                'group-header'?: false | ((args_0: GroupHeaderSlot) => vue.VNodeChild) | undefined;
                'no-data'?: false | (() => vue.VNodeChild) | undefined;
                'expanded-row'?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
                'item.data-table-select'?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
                'item.data-table-expand'?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
            } | undefined;
        } & {
            [x: `v-slot:item.${string}`]: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
            "v-slot:default"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:item"?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
            "v-slot:loading"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:group-header"?: false | ((args_0: GroupHeaderSlot) => vue.VNodeChild) | undefined;
            "v-slot:no-data"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:expanded-row"?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
            "v-slot:item.data-table-select"?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
            "v-slot:item.data-table-expand"?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
        }, {}, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, Record<string, any>, string, {
            noDataText: string;
            loadingText: string;
            items: InternalDataTableItem[];
            hideNoData: boolean;
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & {
        noDataText: string;
        loadingText: string;
        items: InternalDataTableItem[];
        hideNoData: boolean;
    } & {
        loading?: string | boolean | undefined;
        rowHeight?: number | undefined;
        'onClick:row'?: ((e: Event, value: {
            item: DataTableItem;
        }) => void) | undefined;
    } & {
        $children?: vue.VNodeChild | (() => vue.VNodeChild) | {
            [x: `item.${string}`]: ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
            default?: (() => vue.VNodeChild) | undefined;
            item?: ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
            loading?: (() => vue.VNodeChild) | undefined;
            'group-header'?: ((args_0: GroupHeaderSlot) => vue.VNodeChild) | undefined;
            'no-data'?: (() => vue.VNodeChild) | undefined;
            'expanded-row'?: ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
            'item.data-table-select'?: ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
            'item.data-table-expand'?: ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
        };
        'v-slots'?: {
            [x: `item.${string}`]: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
            default?: false | (() => vue.VNodeChild) | undefined;
            item?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
            loading?: false | (() => vue.VNodeChild) | undefined;
            'group-header'?: false | ((args_0: GroupHeaderSlot) => vue.VNodeChild) | undefined;
            'no-data'?: false | (() => vue.VNodeChild) | undefined;
            'expanded-row'?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
            'item.data-table-select'?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
            'item.data-table-expand'?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
        } | undefined;
    } & {
        [x: `v-slot:item.${string}`]: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
        "v-slot:default"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:item"?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
        "v-slot:loading"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:group-header"?: false | ((args_0: GroupHeaderSlot) => vue.VNodeChild) | undefined;
        "v-slot:no-data"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:expanded-row"?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
        "v-slot:item.data-table-select"?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
        "v-slot:item.data-table-expand"?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
    } & vue.ShallowUnwrapRef<{}> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<{
    noDataText: string;
    loadingText: string;
    items: InternalDataTableItem[];
    hideNoData: boolean;
} & {
    loading?: string | boolean | undefined;
    rowHeight?: number | undefined;
    'onClick:row'?: ((e: Event, value: {
        item: DataTableItem;
    }) => void) | undefined;
} & {
    $children?: vue.VNodeChild | (() => vue.VNodeChild) | {
        [x: `item.${string}`]: ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
        default?: (() => vue.VNodeChild) | undefined;
        item?: ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
        loading?: (() => vue.VNodeChild) | undefined;
        'group-header'?: ((args_0: GroupHeaderSlot) => vue.VNodeChild) | undefined;
        'no-data'?: (() => vue.VNodeChild) | undefined;
        'expanded-row'?: ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
        'item.data-table-select'?: ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
        'item.data-table-expand'?: ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
    };
    'v-slots'?: {
        [x: `item.${string}`]: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
        default?: false | (() => vue.VNodeChild) | undefined;
        item?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
        loading?: false | (() => vue.VNodeChild) | undefined;
        'group-header'?: false | ((args_0: GroupHeaderSlot) => vue.VNodeChild) | undefined;
        'no-data'?: false | (() => vue.VNodeChild) | undefined;
        'expanded-row'?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
        'item.data-table-select'?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
        'item.data-table-expand'?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
    } | undefined;
} & {
    [x: `v-slot:item.${string}`]: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
    "v-slot:default"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:item"?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
    "v-slot:loading"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:group-header"?: false | ((args_0: GroupHeaderSlot) => vue.VNodeChild) | undefined;
    "v-slot:no-data"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:expanded-row"?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
    "v-slot:item.data-table-select"?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
    "v-slot:item.data-table-expand"?: false | ((args_0: ItemSlot) => vue.VNodeChild) | undefined;
}, {}, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, Record<string, any>, string, {
    noDataText: string;
    loadingText: string;
    items: InternalDataTableItem[];
    hideNoData: boolean;
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & FilterPropsOptions<{
    loading: (StringConstructor | BooleanConstructor)[];
    loadingText: {
        type: StringConstructor;
        default: string;
    };
    hideNoData: BooleanConstructor;
    items: {
        type: PropType<InternalDataTableItem[]>;
        default: () => never[];
    };
    noDataText: {
        type: StringConstructor;
        default: string;
    };
    rowHeight: NumberConstructor;
    'onClick:row': PropType<(e: Event, value: {
        item: DataTableItem;
    }) => void>;
}, vue.ExtractPropTypes<{
    loading: (StringConstructor | BooleanConstructor)[];
    loadingText: {
        type: StringConstructor;
        default: string;
    };
    hideNoData: BooleanConstructor;
    items: {
        type: PropType<InternalDataTableItem[]>;
        default: () => never[];
    };
    noDataText: {
        type: StringConstructor;
        default: string;
    };
    rowHeight: NumberConstructor;
    'onClick:row': PropType<(e: Event, value: {
        item: DataTableItem;
    }) => void>;
}>>;
type VDataTableRows = InstanceType<typeof VDataTableRows>;

declare const VDataTable: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            style: vue.StyleValue;
            expanded: string[];
            tag: string;
            page: string | number;
            sticky: boolean;
            headers: DataTableHeader[] | DataTableHeader[][];
            noDataText: string;
            loadingText: string;
            itemsPerPageText: string;
            sortBy: SortItem[];
            pageText: string;
            items: any[];
            density: Density;
            modelValue: any[];
            itemTitle: SelectItemKey;
            itemValue: NonNullable<SelectItemKey>;
            itemChildren: SelectItemKey;
            itemProps: SelectItemKey;
            returnObject: boolean;
            hideNoData: boolean;
            filterMode: FilterMode;
            noFilter: boolean;
            hover: boolean;
            nextIcon: string;
            prevIcon: string;
            firstIcon: string;
            lastIcon: string;
            fixedHeader: boolean;
            fixedFooter: boolean;
            itemsPerPage: string | number;
            firstPageLabel: string;
            prevPageLabel: string;
            nextPageLabel: string;
            lastPageLabel: string;
            itemsPerPageOptions: {
                title: string;
                value: number;
            }[];
            showCurrentPage: boolean;
            multiSort: boolean;
            mustSort: boolean;
            groupBy: SortItem[];
            showSelect: boolean;
            sortAscIcon: IconValue;
            sortDescIcon: IconValue;
            expandOnClick: boolean;
            showExpand: boolean;
        }> & Omit<{
            style: vue.StyleValue;
            expanded: string[];
            tag: string;
            page: string | number;
            sticky: boolean;
            headers: DataTableHeader[] | DataTableHeader[][];
            noDataText: string;
            loadingText: string;
            itemsPerPageText: string;
            sortBy: SortItem[];
            pageText: string;
            items: any[];
            density: Density;
            modelValue: any[];
            itemTitle: SelectItemKey;
            itemValue: NonNullable<SelectItemKey>;
            itemChildren: SelectItemKey;
            itemProps: SelectItemKey;
            returnObject: boolean;
            hideNoData: boolean;
            filterMode: FilterMode;
            noFilter: boolean;
            hover: boolean;
            nextIcon: string;
            prevIcon: string;
            firstIcon: string;
            lastIcon: string;
            fixedHeader: boolean;
            fixedFooter: boolean;
            itemsPerPage: string | number;
            firstPageLabel: string;
            prevPageLabel: string;
            nextPageLabel: string;
            lastPageLabel: string;
            itemsPerPageOptions: {
                title: string;
                value: number;
            }[];
            showCurrentPage: boolean;
            multiSort: boolean;
            mustSort: boolean;
            groupBy: SortItem[];
            showSelect: boolean;
            sortAscIcon: IconValue;
            sortDescIcon: IconValue;
            expandOnClick: boolean;
            showExpand: boolean;
        } & {
            search?: string | undefined;
            height?: string | number | undefined;
            width?: string | number | undefined;
            color?: string | undefined;
            loading?: string | boolean | undefined;
            class?: any;
            theme?: string | undefined;
            customFilter?: FilterFunction | undefined;
            customKeyFilter?: FilterKeyFunctions | undefined;
            filterKeys?: FilterKeys | undefined;
            rowHeight?: number | undefined;
            'onClick:row'?: ((e: Event, value: {
                item: DataTableItem;
            }) => void) | undefined;
        } & {
            $children?: vue.VNodeChild | (() => vue.VNodeChild) | {
                [x: `item.${string}`]: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                default?: (() => vue.VNodeChild) | undefined;
                item?: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                loading?: (() => vue.VNodeChild) | undefined;
                'group-header'?: ((args_0: {
                    index: number;
                    item: GroupHeaderItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                    toggleGroup: (group: GroupHeaderItem) => void;
                    isGroupOpen: (group: GroupHeaderItem) => boolean;
                }) => vue.VNodeChild) | undefined;
                'no-data'?: (() => vue.VNodeChild) | undefined;
                'expanded-row'?: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                'item.data-table-select'?: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                'item.data-table-expand'?: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                colgroup?: ((args_0: InternalDataTableHeader) => vue.VNodeChild) | undefined;
                top?: (() => vue.VNodeChild) | undefined;
                headers?: (() => vue.VNodeChild) | undefined;
                body?: (() => vue.VNodeChild) | undefined;
                tbody?: (() => vue.VNodeChild) | undefined;
                thead?: (() => vue.VNodeChild) | undefined;
                tfoot?: (() => vue.VNodeChild) | undefined;
                bottom?: (() => vue.VNodeChild) | undefined;
                'footer.prepend'?: (() => vue.VNodeChild) | undefined;
            };
            'v-slots'?: {
                [x: `item.${string}`]: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                default?: false | (() => vue.VNodeChild) | undefined;
                item?: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                loading?: false | (() => vue.VNodeChild) | undefined;
                'group-header'?: false | ((args_0: {
                    index: number;
                    item: GroupHeaderItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                    toggleGroup: (group: GroupHeaderItem) => void;
                    isGroupOpen: (group: GroupHeaderItem) => boolean;
                }) => vue.VNodeChild) | undefined;
                'no-data'?: false | (() => vue.VNodeChild) | undefined;
                'expanded-row'?: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                'item.data-table-select'?: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                'item.data-table-expand'?: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                colgroup?: false | ((args_0: InternalDataTableHeader) => vue.VNodeChild) | undefined;
                top?: false | (() => vue.VNodeChild) | undefined;
                headers?: false | (() => vue.VNodeChild) | undefined;
                body?: false | (() => vue.VNodeChild) | undefined;
                tbody?: false | (() => vue.VNodeChild) | undefined;
                thead?: false | (() => vue.VNodeChild) | undefined;
                tfoot?: false | (() => vue.VNodeChild) | undefined;
                bottom?: false | (() => vue.VNodeChild) | undefined;
                'footer.prepend'?: false | (() => vue.VNodeChild) | undefined;
            } | undefined;
        } & {
            [x: `v-slot:item.${string}`]: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:default"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:item"?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:loading"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:group-header"?: false | ((args_0: {
                index: number;
                item: GroupHeaderItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
                toggleGroup: (group: GroupHeaderItem) => void;
                isGroupOpen: (group: GroupHeaderItem) => boolean;
            }) => vue.VNodeChild) | undefined;
            "v-slot:no-data"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:expanded-row"?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:item.data-table-select"?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:item.data-table-expand"?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:colgroup"?: false | ((args_0: InternalDataTableHeader) => vue.VNodeChild) | undefined;
            "v-slot:top"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:headers"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:body"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:tbody"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:thead"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:tfoot"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:bottom"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:footer.prepend"?: false | (() => vue.VNodeChild) | undefined;
        } & {
            "onUpdate:modelValue"?: ((value: any[]) => any) | undefined;
            "onUpdate:page"?: ((value: number) => any) | undefined;
            "onUpdate:itemsPerPage"?: ((value: number) => any) | undefined;
            "onUpdate:sortBy"?: ((value: any) => any) | undefined;
            "onUpdate:groupBy"?: ((value: any) => any) | undefined;
            "onUpdate:expanded"?: ((value: any) => any) | undefined;
            "onUpdate:options"?: ((value: any) => any) | undefined;
        } & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "style" | "expanded" | "tag" | "page" | "sticky" | "headers" | "noDataText" | "loadingText" | "itemsPerPageText" | "sortBy" | "pageText" | "items" | "density" | "modelValue" | "itemTitle" | "itemValue" | "itemChildren" | "itemProps" | "returnObject" | "hideNoData" | "filterMode" | "noFilter" | "hover" | "nextIcon" | "prevIcon" | "firstIcon" | "lastIcon" | "fixedHeader" | "fixedFooter" | "itemsPerPage" | "firstPageLabel" | "prevPageLabel" | "nextPageLabel" | "lastPageLabel" | "itemsPerPageOptions" | "showCurrentPage" | "multiSort" | "mustSort" | "groupBy" | "showSelect" | "sortAscIcon" | "sortDescIcon" | "expandOnClick" | "showExpand">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: ((event: "update:modelValue", value: any[]) => void) & ((event: "update:options", value: any) => void) & ((event: "update:page", value: number) => void) & ((event: "update:itemsPerPage", value: number) => void) & ((event: "update:sortBy", value: any) => void) & ((event: "update:groupBy", value: any) => void) & ((event: "update:expanded", value: any) => void);
        $el: any;
        $options: vue.ComponentOptionsBase<{
            style: vue.StyleValue;
            expanded: string[];
            tag: string;
            page: string | number;
            sticky: boolean;
            headers: DataTableHeader[] | DataTableHeader[][];
            noDataText: string;
            loadingText: string;
            itemsPerPageText: string;
            sortBy: SortItem[];
            pageText: string;
            items: any[];
            density: Density;
            modelValue: any[];
            itemTitle: SelectItemKey;
            itemValue: NonNullable<SelectItemKey>;
            itemChildren: SelectItemKey;
            itemProps: SelectItemKey;
            returnObject: boolean;
            hideNoData: boolean;
            filterMode: FilterMode;
            noFilter: boolean;
            hover: boolean;
            nextIcon: string;
            prevIcon: string;
            firstIcon: string;
            lastIcon: string;
            fixedHeader: boolean;
            fixedFooter: boolean;
            itemsPerPage: string | number;
            firstPageLabel: string;
            prevPageLabel: string;
            nextPageLabel: string;
            lastPageLabel: string;
            itemsPerPageOptions: {
                title: string;
                value: number;
            }[];
            showCurrentPage: boolean;
            multiSort: boolean;
            mustSort: boolean;
            groupBy: SortItem[];
            showSelect: boolean;
            sortAscIcon: IconValue;
            sortDescIcon: IconValue;
            expandOnClick: boolean;
            showExpand: boolean;
        } & {
            search?: string | undefined;
            height?: string | number | undefined;
            width?: string | number | undefined;
            color?: string | undefined;
            loading?: string | boolean | undefined;
            class?: any;
            theme?: string | undefined;
            customFilter?: FilterFunction | undefined;
            customKeyFilter?: FilterKeyFunctions | undefined;
            filterKeys?: FilterKeys | undefined;
            rowHeight?: number | undefined;
            'onClick:row'?: ((e: Event, value: {
                item: DataTableItem;
            }) => void) | undefined;
        } & {
            $children?: vue.VNodeChild | (() => vue.VNodeChild) | {
                [x: `item.${string}`]: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                default?: (() => vue.VNodeChild) | undefined;
                item?: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                loading?: (() => vue.VNodeChild) | undefined;
                'group-header'?: ((args_0: {
                    index: number;
                    item: GroupHeaderItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                    toggleGroup: (group: GroupHeaderItem) => void;
                    isGroupOpen: (group: GroupHeaderItem) => boolean;
                }) => vue.VNodeChild) | undefined;
                'no-data'?: (() => vue.VNodeChild) | undefined;
                'expanded-row'?: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                'item.data-table-select'?: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                'item.data-table-expand'?: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                colgroup?: ((args_0: InternalDataTableHeader) => vue.VNodeChild) | undefined;
                top?: (() => vue.VNodeChild) | undefined;
                headers?: (() => vue.VNodeChild) | undefined;
                body?: (() => vue.VNodeChild) | undefined;
                tbody?: (() => vue.VNodeChild) | undefined;
                thead?: (() => vue.VNodeChild) | undefined;
                tfoot?: (() => vue.VNodeChild) | undefined;
                bottom?: (() => vue.VNodeChild) | undefined;
                'footer.prepend'?: (() => vue.VNodeChild) | undefined;
            };
            'v-slots'?: {
                [x: `item.${string}`]: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                default?: false | (() => vue.VNodeChild) | undefined;
                item?: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                loading?: false | (() => vue.VNodeChild) | undefined;
                'group-header'?: false | ((args_0: {
                    index: number;
                    item: GroupHeaderItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                    toggleGroup: (group: GroupHeaderItem) => void;
                    isGroupOpen: (group: GroupHeaderItem) => boolean;
                }) => vue.VNodeChild) | undefined;
                'no-data'?: false | (() => vue.VNodeChild) | undefined;
                'expanded-row'?: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                'item.data-table-select'?: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                'item.data-table-expand'?: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                colgroup?: false | ((args_0: InternalDataTableHeader) => vue.VNodeChild) | undefined;
                top?: false | (() => vue.VNodeChild) | undefined;
                headers?: false | (() => vue.VNodeChild) | undefined;
                body?: false | (() => vue.VNodeChild) | undefined;
                tbody?: false | (() => vue.VNodeChild) | undefined;
                thead?: false | (() => vue.VNodeChild) | undefined;
                tfoot?: false | (() => vue.VNodeChild) | undefined;
                bottom?: false | (() => vue.VNodeChild) | undefined;
                'footer.prepend'?: false | (() => vue.VNodeChild) | undefined;
            } | undefined;
        } & {
            [x: `v-slot:item.${string}`]: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:default"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:item"?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:loading"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:group-header"?: false | ((args_0: {
                index: number;
                item: GroupHeaderItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
                toggleGroup: (group: GroupHeaderItem) => void;
                isGroupOpen: (group: GroupHeaderItem) => boolean;
            }) => vue.VNodeChild) | undefined;
            "v-slot:no-data"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:expanded-row"?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:item.data-table-select"?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:item.data-table-expand"?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:colgroup"?: false | ((args_0: InternalDataTableHeader) => vue.VNodeChild) | undefined;
            "v-slot:top"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:headers"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:body"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:tbody"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:thead"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:tfoot"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:bottom"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:footer.prepend"?: false | (() => vue.VNodeChild) | undefined;
        } & {
            "onUpdate:modelValue"?: ((value: any[]) => any) | undefined;
            "onUpdate:page"?: ((value: number) => any) | undefined;
            "onUpdate:itemsPerPage"?: ((value: number) => any) | undefined;
            "onUpdate:sortBy"?: ((value: any) => any) | undefined;
            "onUpdate:groupBy"?: ((value: any) => any) | undefined;
            "onUpdate:expanded"?: ((value: any) => any) | undefined;
            "onUpdate:options"?: ((value: any) => any) | undefined;
        }, {}, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
            'update:modelValue': (value: any[]) => true;
            'update:page': (value: number) => true;
            'update:itemsPerPage': (value: number) => true;
            'update:sortBy': (value: any) => true;
            'update:options': (value: any) => true;
            'update:groupBy': (value: any) => true;
            'update:expanded': (value: any) => true;
        }, string, {
            style: vue.StyleValue;
            expanded: string[];
            tag: string;
            page: string | number;
            sticky: boolean;
            headers: DataTableHeader[] | DataTableHeader[][];
            noDataText: string;
            loadingText: string;
            itemsPerPageText: string;
            sortBy: SortItem[];
            pageText: string;
            items: any[];
            density: Density;
            modelValue: any[];
            itemTitle: SelectItemKey;
            itemValue: NonNullable<SelectItemKey>;
            itemChildren: SelectItemKey;
            itemProps: SelectItemKey;
            returnObject: boolean;
            hideNoData: boolean;
            filterMode: FilterMode;
            noFilter: boolean;
            hover: boolean;
            nextIcon: string;
            prevIcon: string;
            firstIcon: string;
            lastIcon: string;
            fixedHeader: boolean;
            fixedFooter: boolean;
            itemsPerPage: string | number;
            firstPageLabel: string;
            prevPageLabel: string;
            nextPageLabel: string;
            lastPageLabel: string;
            itemsPerPageOptions: {
                title: string;
                value: number;
            }[];
            showCurrentPage: boolean;
            multiSort: boolean;
            mustSort: boolean;
            groupBy: SortItem[];
            showSelect: boolean;
            sortAscIcon: IconValue;
            sortDescIcon: IconValue;
            expandOnClick: boolean;
            showExpand: boolean;
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & {
        style: vue.StyleValue;
        expanded: string[];
        tag: string;
        page: string | number;
        sticky: boolean;
        headers: DataTableHeader[] | DataTableHeader[][];
        noDataText: string;
        loadingText: string;
        itemsPerPageText: string;
        sortBy: SortItem[];
        pageText: string;
        items: any[];
        density: Density;
        modelValue: any[];
        itemTitle: SelectItemKey;
        itemValue: NonNullable<SelectItemKey>;
        itemChildren: SelectItemKey;
        itemProps: SelectItemKey;
        returnObject: boolean;
        hideNoData: boolean;
        filterMode: FilterMode;
        noFilter: boolean;
        hover: boolean;
        nextIcon: string;
        prevIcon: string;
        firstIcon: string;
        lastIcon: string;
        fixedHeader: boolean;
        fixedFooter: boolean;
        itemsPerPage: string | number;
        firstPageLabel: string;
        prevPageLabel: string;
        nextPageLabel: string;
        lastPageLabel: string;
        itemsPerPageOptions: {
            title: string;
            value: number;
        }[];
        showCurrentPage: boolean;
        multiSort: boolean;
        mustSort: boolean;
        groupBy: SortItem[];
        showSelect: boolean;
        sortAscIcon: IconValue;
        sortDescIcon: IconValue;
        expandOnClick: boolean;
        showExpand: boolean;
    } & {
        search?: string | undefined;
        height?: string | number | undefined;
        width?: string | number | undefined;
        color?: string | undefined;
        loading?: string | boolean | undefined;
        class?: any;
        theme?: string | undefined;
        customFilter?: FilterFunction | undefined;
        customKeyFilter?: FilterKeyFunctions | undefined;
        filterKeys?: FilterKeys | undefined;
        rowHeight?: number | undefined;
        'onClick:row'?: ((e: Event, value: {
            item: DataTableItem;
        }) => void) | undefined;
    } & {
        $children?: vue.VNodeChild | (() => vue.VNodeChild) | {
            [x: `item.${string}`]: ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            default?: (() => vue.VNodeChild) | undefined;
            item?: ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            loading?: (() => vue.VNodeChild) | undefined;
            'group-header'?: ((args_0: {
                index: number;
                item: GroupHeaderItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
                toggleGroup: (group: GroupHeaderItem) => void;
                isGroupOpen: (group: GroupHeaderItem) => boolean;
            }) => vue.VNodeChild) | undefined;
            'no-data'?: (() => vue.VNodeChild) | undefined;
            'expanded-row'?: ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            'item.data-table-select'?: ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            'item.data-table-expand'?: ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            colgroup?: ((args_0: InternalDataTableHeader) => vue.VNodeChild) | undefined;
            top?: (() => vue.VNodeChild) | undefined;
            headers?: (() => vue.VNodeChild) | undefined;
            body?: (() => vue.VNodeChild) | undefined;
            tbody?: (() => vue.VNodeChild) | undefined;
            thead?: (() => vue.VNodeChild) | undefined;
            tfoot?: (() => vue.VNodeChild) | undefined;
            bottom?: (() => vue.VNodeChild) | undefined;
            'footer.prepend'?: (() => vue.VNodeChild) | undefined;
        };
        'v-slots'?: {
            [x: `item.${string}`]: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            default?: false | (() => vue.VNodeChild) | undefined;
            item?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            loading?: false | (() => vue.VNodeChild) | undefined;
            'group-header'?: false | ((args_0: {
                index: number;
                item: GroupHeaderItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
                toggleGroup: (group: GroupHeaderItem) => void;
                isGroupOpen: (group: GroupHeaderItem) => boolean;
            }) => vue.VNodeChild) | undefined;
            'no-data'?: false | (() => vue.VNodeChild) | undefined;
            'expanded-row'?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            'item.data-table-select'?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            'item.data-table-expand'?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            colgroup?: false | ((args_0: InternalDataTableHeader) => vue.VNodeChild) | undefined;
            top?: false | (() => vue.VNodeChild) | undefined;
            headers?: false | (() => vue.VNodeChild) | undefined;
            body?: false | (() => vue.VNodeChild) | undefined;
            tbody?: false | (() => vue.VNodeChild) | undefined;
            thead?: false | (() => vue.VNodeChild) | undefined;
            tfoot?: false | (() => vue.VNodeChild) | undefined;
            bottom?: false | (() => vue.VNodeChild) | undefined;
            'footer.prepend'?: false | (() => vue.VNodeChild) | undefined;
        } | undefined;
    } & {
        [x: `v-slot:item.${string}`]: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        "v-slot:default"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:item"?: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        "v-slot:loading"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:group-header"?: false | ((args_0: {
            index: number;
            item: GroupHeaderItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
            toggleGroup: (group: GroupHeaderItem) => void;
            isGroupOpen: (group: GroupHeaderItem) => boolean;
        }) => vue.VNodeChild) | undefined;
        "v-slot:no-data"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:expanded-row"?: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        "v-slot:item.data-table-select"?: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        "v-slot:item.data-table-expand"?: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        "v-slot:colgroup"?: false | ((args_0: InternalDataTableHeader) => vue.VNodeChild) | undefined;
        "v-slot:top"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:headers"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:body"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:tbody"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:thead"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:tfoot"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:bottom"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:footer.prepend"?: false | (() => vue.VNodeChild) | undefined;
    } & {
        "onUpdate:modelValue"?: ((value: any[]) => any) | undefined;
        "onUpdate:page"?: ((value: number) => any) | undefined;
        "onUpdate:itemsPerPage"?: ((value: number) => any) | undefined;
        "onUpdate:sortBy"?: ((value: any) => any) | undefined;
        "onUpdate:groupBy"?: ((value: any) => any) | undefined;
        "onUpdate:expanded"?: ((value: any) => any) | undefined;
        "onUpdate:options"?: ((value: any) => any) | undefined;
    } & vue.ShallowUnwrapRef<{}> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<{
    style: vue.StyleValue;
    expanded: string[];
    tag: string;
    page: string | number;
    sticky: boolean;
    headers: DataTableHeader[] | DataTableHeader[][];
    noDataText: string;
    loadingText: string;
    itemsPerPageText: string;
    sortBy: SortItem[];
    pageText: string;
    items: any[];
    density: Density;
    modelValue: any[];
    itemTitle: SelectItemKey;
    itemValue: NonNullable<SelectItemKey>;
    itemChildren: SelectItemKey;
    itemProps: SelectItemKey;
    returnObject: boolean;
    hideNoData: boolean;
    filterMode: FilterMode;
    noFilter: boolean;
    hover: boolean;
    nextIcon: string;
    prevIcon: string;
    firstIcon: string;
    lastIcon: string;
    fixedHeader: boolean;
    fixedFooter: boolean;
    itemsPerPage: string | number;
    firstPageLabel: string;
    prevPageLabel: string;
    nextPageLabel: string;
    lastPageLabel: string;
    itemsPerPageOptions: {
        title: string;
        value: number;
    }[];
    showCurrentPage: boolean;
    multiSort: boolean;
    mustSort: boolean;
    groupBy: SortItem[];
    showSelect: boolean;
    sortAscIcon: IconValue;
    sortDescIcon: IconValue;
    expandOnClick: boolean;
    showExpand: boolean;
} & {
    search?: string | undefined;
    height?: string | number | undefined;
    width?: string | number | undefined;
    color?: string | undefined;
    loading?: string | boolean | undefined;
    class?: any;
    theme?: string | undefined;
    customFilter?: FilterFunction | undefined;
    customKeyFilter?: FilterKeyFunctions | undefined;
    filterKeys?: FilterKeys | undefined;
    rowHeight?: number | undefined;
    'onClick:row'?: ((e: Event, value: {
        item: DataTableItem;
    }) => void) | undefined;
} & {
    $children?: vue.VNodeChild | (() => vue.VNodeChild) | {
        [x: `item.${string}`]: ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        default?: (() => vue.VNodeChild) | undefined;
        item?: ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        loading?: (() => vue.VNodeChild) | undefined;
        'group-header'?: ((args_0: {
            index: number;
            item: GroupHeaderItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
            toggleGroup: (group: GroupHeaderItem) => void;
            isGroupOpen: (group: GroupHeaderItem) => boolean;
        }) => vue.VNodeChild) | undefined;
        'no-data'?: (() => vue.VNodeChild) | undefined;
        'expanded-row'?: ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        'item.data-table-select'?: ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        'item.data-table-expand'?: ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        colgroup?: ((args_0: InternalDataTableHeader) => vue.VNodeChild) | undefined;
        top?: (() => vue.VNodeChild) | undefined;
        headers?: (() => vue.VNodeChild) | undefined;
        body?: (() => vue.VNodeChild) | undefined;
        tbody?: (() => vue.VNodeChild) | undefined;
        thead?: (() => vue.VNodeChild) | undefined;
        tfoot?: (() => vue.VNodeChild) | undefined;
        bottom?: (() => vue.VNodeChild) | undefined;
        'footer.prepend'?: (() => vue.VNodeChild) | undefined;
    };
    'v-slots'?: {
        [x: `item.${string}`]: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        default?: false | (() => vue.VNodeChild) | undefined;
        item?: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        loading?: false | (() => vue.VNodeChild) | undefined;
        'group-header'?: false | ((args_0: {
            index: number;
            item: GroupHeaderItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
            toggleGroup: (group: GroupHeaderItem) => void;
            isGroupOpen: (group: GroupHeaderItem) => boolean;
        }) => vue.VNodeChild) | undefined;
        'no-data'?: false | (() => vue.VNodeChild) | undefined;
        'expanded-row'?: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        'item.data-table-select'?: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        'item.data-table-expand'?: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        colgroup?: false | ((args_0: InternalDataTableHeader) => vue.VNodeChild) | undefined;
        top?: false | (() => vue.VNodeChild) | undefined;
        headers?: false | (() => vue.VNodeChild) | undefined;
        body?: false | (() => vue.VNodeChild) | undefined;
        tbody?: false | (() => vue.VNodeChild) | undefined;
        thead?: false | (() => vue.VNodeChild) | undefined;
        tfoot?: false | (() => vue.VNodeChild) | undefined;
        bottom?: false | (() => vue.VNodeChild) | undefined;
        'footer.prepend'?: false | (() => vue.VNodeChild) | undefined;
    } | undefined;
} & {
    [x: `v-slot:item.${string}`]: false | ((args_0: {
        index: number;
        item: DataTableItem;
        columns: InternalDataTableHeader[];
        isExpanded: (item: DataTableItem) => boolean;
        toggleExpand: (item: DataTableItem) => void;
        isSelected: (items: DataTableItem[]) => boolean;
        toggleSelect: (item: DataTableItem) => void;
    }) => vue.VNodeChild) | undefined;
    "v-slot:default"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:item"?: false | ((args_0: {
        index: number;
        item: DataTableItem;
        columns: InternalDataTableHeader[];
        isExpanded: (item: DataTableItem) => boolean;
        toggleExpand: (item: DataTableItem) => void;
        isSelected: (items: DataTableItem[]) => boolean;
        toggleSelect: (item: DataTableItem) => void;
    }) => vue.VNodeChild) | undefined;
    "v-slot:loading"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:group-header"?: false | ((args_0: {
        index: number;
        item: GroupHeaderItem;
        columns: InternalDataTableHeader[];
        isExpanded: (item: DataTableItem) => boolean;
        toggleExpand: (item: DataTableItem) => void;
        isSelected: (items: DataTableItem[]) => boolean;
        toggleSelect: (item: DataTableItem) => void;
        toggleGroup: (group: GroupHeaderItem) => void;
        isGroupOpen: (group: GroupHeaderItem) => boolean;
    }) => vue.VNodeChild) | undefined;
    "v-slot:no-data"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:expanded-row"?: false | ((args_0: {
        index: number;
        item: DataTableItem;
        columns: InternalDataTableHeader[];
        isExpanded: (item: DataTableItem) => boolean;
        toggleExpand: (item: DataTableItem) => void;
        isSelected: (items: DataTableItem[]) => boolean;
        toggleSelect: (item: DataTableItem) => void;
    }) => vue.VNodeChild) | undefined;
    "v-slot:item.data-table-select"?: false | ((args_0: {
        index: number;
        item: DataTableItem;
        columns: InternalDataTableHeader[];
        isExpanded: (item: DataTableItem) => boolean;
        toggleExpand: (item: DataTableItem) => void;
        isSelected: (items: DataTableItem[]) => boolean;
        toggleSelect: (item: DataTableItem) => void;
    }) => vue.VNodeChild) | undefined;
    "v-slot:item.data-table-expand"?: false | ((args_0: {
        index: number;
        item: DataTableItem;
        columns: InternalDataTableHeader[];
        isExpanded: (item: DataTableItem) => boolean;
        toggleExpand: (item: DataTableItem) => void;
        isSelected: (items: DataTableItem[]) => boolean;
        toggleSelect: (item: DataTableItem) => void;
    }) => vue.VNodeChild) | undefined;
    "v-slot:colgroup"?: false | ((args_0: InternalDataTableHeader) => vue.VNodeChild) | undefined;
    "v-slot:top"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:headers"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:body"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:tbody"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:thead"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:tfoot"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:bottom"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:footer.prepend"?: false | (() => vue.VNodeChild) | undefined;
} & {
    "onUpdate:modelValue"?: ((value: any[]) => any) | undefined;
    "onUpdate:page"?: ((value: number) => any) | undefined;
    "onUpdate:itemsPerPage"?: ((value: number) => any) | undefined;
    "onUpdate:sortBy"?: ((value: any) => any) | undefined;
    "onUpdate:groupBy"?: ((value: any) => any) | undefined;
    "onUpdate:expanded"?: ((value: any) => any) | undefined;
    "onUpdate:options"?: ((value: any) => any) | undefined;
}, {}, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (value: any[]) => true;
    'update:page': (value: number) => true;
    'update:itemsPerPage': (value: number) => true;
    'update:sortBy': (value: any) => true;
    'update:options': (value: any) => true;
    'update:groupBy': (value: any) => true;
    'update:expanded': (value: any) => true;
}, string, {
    style: vue.StyleValue;
    expanded: string[];
    tag: string;
    page: string | number;
    sticky: boolean;
    headers: DataTableHeader[] | DataTableHeader[][];
    noDataText: string;
    loadingText: string;
    itemsPerPageText: string;
    sortBy: SortItem[];
    pageText: string;
    items: any[];
    density: Density;
    modelValue: any[];
    itemTitle: SelectItemKey;
    itemValue: NonNullable<SelectItemKey>;
    itemChildren: SelectItemKey;
    itemProps: SelectItemKey;
    returnObject: boolean;
    hideNoData: boolean;
    filterMode: FilterMode;
    noFilter: boolean;
    hover: boolean;
    nextIcon: string;
    prevIcon: string;
    firstIcon: string;
    lastIcon: string;
    fixedHeader: boolean;
    fixedFooter: boolean;
    itemsPerPage: string | number;
    firstPageLabel: string;
    prevPageLabel: string;
    nextPageLabel: string;
    lastPageLabel: string;
    itemsPerPageOptions: {
        title: string;
        value: number;
    }[];
    showCurrentPage: boolean;
    multiSort: boolean;
    mustSort: boolean;
    groupBy: SortItem[];
    showSelect: boolean;
    sortAscIcon: IconValue;
    sortDescIcon: IconValue;
    expandOnClick: boolean;
    showExpand: boolean;
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & FilterPropsOptions<{
    prevIcon: {
        type: StringConstructor;
        default: string;
    };
    nextIcon: {
        type: StringConstructor;
        default: string;
    };
    firstIcon: {
        type: StringConstructor;
        default: string;
    };
    lastIcon: {
        type: StringConstructor;
        default: string;
    };
    itemsPerPageText: {
        type: StringConstructor;
        default: string;
    };
    pageText: {
        type: StringConstructor;
        default: string;
    };
    firstPageLabel: {
        type: StringConstructor;
        default: string;
    };
    prevPageLabel: {
        type: StringConstructor;
        default: string;
    };
    nextPageLabel: {
        type: StringConstructor;
        default: string;
    };
    lastPageLabel: {
        type: StringConstructor;
        default: string;
    };
    itemsPerPageOptions: {
        type: vue.PropType<{
            title: string;
            value: number;
        }[]>;
        default: () => {
            value: number;
            title: string;
        }[];
    };
    showCurrentPage: BooleanConstructor;
    customFilter: vue.PropType<FilterFunction>;
    customKeyFilter: vue.PropType<FilterKeyFunctions>;
    filterKeys: vue.PropType<FilterKeys>;
    filterMode: {
        type: vue.PropType<FilterMode>;
        default: string;
    };
    noFilter: BooleanConstructor;
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    density: {
        type: vue.PropType<Density>;
        default: string;
        validator: (v: any) => boolean;
    };
    class: vue.PropType<any>;
    style: {
        type: vue.PropType<vue.StyleValue>;
        default: null;
    };
    fixedHeader: BooleanConstructor;
    fixedFooter: BooleanConstructor;
    height: (StringConstructor | NumberConstructor)[];
    hover: BooleanConstructor;
    loading: (StringConstructor | BooleanConstructor)[];
    color: StringConstructor;
    sticky: BooleanConstructor;
    multiSort: BooleanConstructor;
    sortAscIcon: {
        type: vue.PropType<IconValue>;
        default: string;
    };
    sortDescIcon: {
        type: vue.PropType<IconValue>;
        default: string;
    };
    sortBy: {
        type: vue.PropType<SortItem[]>;
        default: () => never[];
    };
    mustSort: BooleanConstructor;
    showSelect: BooleanConstructor;
    modelValue: {
        type: vue.PropType<any[]>;
        default: () => never[];
    };
    items: {
        type: vue.PropType<any[]>;
        default: () => never[];
    };
    itemTitle: {
        type: vue.PropType<SelectItemKey>;
        default: string;
    };
    itemValue: Omit<{
        type: vue.PropType<SelectItemKey>;
        default: string;
    }, "type" | "default"> & {
        type: vue.PropType<NonNullable<SelectItemKey>>;
        default: NonNullable<SelectItemKey>;
    };
    itemChildren: {
        type: vue.PropType<SelectItemKey>;
        default: string;
    };
    itemProps: {
        type: vue.PropType<SelectItemKey>;
        default: string;
    };
    returnObject: BooleanConstructor;
    headers: {
        type: vue.PropType<DataTableHeader[] | DataTableHeader[][]>;
        default: () => never[];
    };
    groupBy: {
        type: vue.PropType<SortItem[]>;
        default: () => never[];
    };
    expandOnClick: BooleanConstructor;
    showExpand: BooleanConstructor;
    expanded: {
        type: vue.PropType<string[]>;
        default: () => never[];
    };
    width: (StringConstructor | NumberConstructor)[];
    search: StringConstructor;
    loadingText: {
        type: StringConstructor;
        default: string;
    };
    hideNoData: BooleanConstructor;
    noDataText: {
        type: StringConstructor;
        default: string;
    };
    rowHeight: NumberConstructor;
    'onClick:row': vue.PropType<(e: Event, value: {
        item: DataTableItem;
    }) => void>;
    page: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    itemsPerPage: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
}, vue.ExtractPropTypes<{
    prevIcon: {
        type: StringConstructor;
        default: string;
    };
    nextIcon: {
        type: StringConstructor;
        default: string;
    };
    firstIcon: {
        type: StringConstructor;
        default: string;
    };
    lastIcon: {
        type: StringConstructor;
        default: string;
    };
    itemsPerPageText: {
        type: StringConstructor;
        default: string;
    };
    pageText: {
        type: StringConstructor;
        default: string;
    };
    firstPageLabel: {
        type: StringConstructor;
        default: string;
    };
    prevPageLabel: {
        type: StringConstructor;
        default: string;
    };
    nextPageLabel: {
        type: StringConstructor;
        default: string;
    };
    lastPageLabel: {
        type: StringConstructor;
        default: string;
    };
    itemsPerPageOptions: {
        type: vue.PropType<{
            title: string;
            value: number;
        }[]>;
        default: () => {
            value: number;
            title: string;
        }[];
    };
    showCurrentPage: BooleanConstructor;
    customFilter: vue.PropType<FilterFunction>;
    customKeyFilter: vue.PropType<FilterKeyFunctions>;
    filterKeys: vue.PropType<FilterKeys>;
    filterMode: {
        type: vue.PropType<FilterMode>;
        default: string;
    };
    noFilter: BooleanConstructor;
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    density: {
        type: vue.PropType<Density>;
        default: string;
        validator: (v: any) => boolean;
    };
    class: vue.PropType<any>;
    style: {
        type: vue.PropType<vue.StyleValue>;
        default: null;
    };
    fixedHeader: BooleanConstructor;
    fixedFooter: BooleanConstructor;
    height: (StringConstructor | NumberConstructor)[];
    hover: BooleanConstructor;
    loading: (StringConstructor | BooleanConstructor)[];
    color: StringConstructor;
    sticky: BooleanConstructor;
    multiSort: BooleanConstructor;
    sortAscIcon: {
        type: vue.PropType<IconValue>;
        default: string;
    };
    sortDescIcon: {
        type: vue.PropType<IconValue>;
        default: string;
    };
    sortBy: {
        type: vue.PropType<SortItem[]>;
        default: () => never[];
    };
    mustSort: BooleanConstructor;
    showSelect: BooleanConstructor;
    modelValue: {
        type: vue.PropType<any[]>;
        default: () => never[];
    };
    items: {
        type: vue.PropType<any[]>;
        default: () => never[];
    };
    itemTitle: {
        type: vue.PropType<SelectItemKey>;
        default: string;
    };
    itemValue: Omit<{
        type: vue.PropType<SelectItemKey>;
        default: string;
    }, "type" | "default"> & {
        type: vue.PropType<NonNullable<SelectItemKey>>;
        default: NonNullable<SelectItemKey>;
    };
    itemChildren: {
        type: vue.PropType<SelectItemKey>;
        default: string;
    };
    itemProps: {
        type: vue.PropType<SelectItemKey>;
        default: string;
    };
    returnObject: BooleanConstructor;
    headers: {
        type: vue.PropType<DataTableHeader[] | DataTableHeader[][]>;
        default: () => never[];
    };
    groupBy: {
        type: vue.PropType<SortItem[]>;
        default: () => never[];
    };
    expandOnClick: BooleanConstructor;
    showExpand: BooleanConstructor;
    expanded: {
        type: vue.PropType<string[]>;
        default: () => never[];
    };
    width: (StringConstructor | NumberConstructor)[];
    search: StringConstructor;
    loadingText: {
        type: StringConstructor;
        default: string;
    };
    hideNoData: BooleanConstructor;
    noDataText: {
        type: StringConstructor;
        default: string;
    };
    rowHeight: NumberConstructor;
    'onClick:row': vue.PropType<(e: Event, value: {
        item: DataTableItem;
    }) => void>;
    page: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    itemsPerPage: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
}>>;
type VDataTable = InstanceType<typeof VDataTable>;

declare const VDataTableRow: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{}> & Omit<Readonly<vue.ExtractPropTypes<{
            index: PropType<Number>;
            item: PropType<DataTableItem>;
            onClick: PropType<(e: MouseEvent) => void>;
        }>> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, never>;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: (event: string, ...args: any[]) => void;
        $el: any;
        $options: vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
            index: PropType<Number>;
            item: PropType<DataTableItem>;
            onClick: PropType<(e: MouseEvent) => void>;
        }>>, void, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, {}, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & Readonly<vue.ExtractPropTypes<{
        index: PropType<Number>;
        item: PropType<DataTableItem>;
        onClick: PropType<(e: MouseEvent) => void>;
    }>> & vue.ShallowUnwrapRef<{}> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<Readonly<vue.ExtractPropTypes<{
    index: PropType<Number>;
    item: PropType<DataTableItem>;
    onClick: PropType<(e: MouseEvent) => void>;
}>>, void, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, {}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & FilterPropsOptions<{
    index: PropType<Number>;
    item: PropType<DataTableItem>;
    onClick: PropType<(e: MouseEvent) => void>;
}, vue.ExtractPropTypes<{
    index: PropType<Number>;
    item: PropType<DataTableItem>;
    onClick: PropType<(e: MouseEvent) => void>;
}>>;
type VDataTableRow = InstanceType<typeof VDataTableRow>;

declare const VDataTableVirtual: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            style: vue.StyleValue;
            expanded: string[];
            tag: string;
            sticky: boolean;
            headers: DataTableHeader[] | DataTableHeader[][];
            noDataText: string;
            loadingText: string;
            sortBy: SortItem[];
            items: any[];
            density: Density;
            modelValue: any[];
            itemTitle: SelectItemKey;
            itemValue: NonNullable<SelectItemKey>;
            itemChildren: SelectItemKey;
            itemProps: SelectItemKey;
            returnObject: boolean;
            hideNoData: boolean;
            filterMode: FilterMode;
            noFilter: boolean;
            hover: boolean;
            fixedHeader: boolean;
            fixedFooter: boolean;
            itemHeight: string | number;
            multiSort: boolean;
            mustSort: boolean;
            groupBy: SortItem[];
            showSelect: boolean;
            sortAscIcon: IconValue;
            sortDescIcon: IconValue;
            expandOnClick: boolean;
            showExpand: boolean;
            visibleItems: string | number;
        }> & Omit<{
            style: vue.StyleValue;
            expanded: string[];
            tag: string;
            sticky: boolean;
            headers: DataTableHeader[] | DataTableHeader[][];
            noDataText: string;
            loadingText: string;
            sortBy: SortItem[];
            items: any[];
            density: Density;
            modelValue: any[];
            itemTitle: SelectItemKey;
            itemValue: NonNullable<SelectItemKey>;
            itemChildren: SelectItemKey;
            itemProps: SelectItemKey;
            returnObject: boolean;
            hideNoData: boolean;
            filterMode: FilterMode;
            noFilter: boolean;
            hover: boolean;
            fixedHeader: boolean;
            fixedFooter: boolean;
            itemHeight: string | number;
            multiSort: boolean;
            mustSort: boolean;
            groupBy: SortItem[];
            showSelect: boolean;
            sortAscIcon: IconValue;
            sortDescIcon: IconValue;
            expandOnClick: boolean;
            showExpand: boolean;
            visibleItems: string | number;
        } & {
            search?: string | undefined;
            height?: string | number | undefined;
            width?: string | number | undefined;
            color?: string | undefined;
            loading?: string | boolean | undefined;
            class?: any;
            theme?: string | undefined;
            customFilter?: FilterFunction | undefined;
            customKeyFilter?: FilterKeyFunctions | undefined;
            filterKeys?: FilterKeys | undefined;
            rowHeight?: number | undefined;
            'onClick:row'?: ((e: Event, value: {
                item: DataTableItem;
            }) => void) | undefined;
        } & {
            $children?: vue.VNodeChild | (() => vue.VNodeChild) | {
                [x: `item.${string}`]: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                default?: (() => vue.VNodeChild) | undefined;
                item?: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                loading?: (() => vue.VNodeChild) | undefined;
                'group-header'?: ((args_0: {
                    index: number;
                    item: GroupHeaderItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                    toggleGroup: (group: GroupHeaderItem) => void;
                    isGroupOpen: (group: GroupHeaderItem) => boolean;
                }) => vue.VNodeChild) | undefined;
                'no-data'?: (() => vue.VNodeChild) | undefined;
                'expanded-row'?: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                'item.data-table-select'?: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                'item.data-table-expand'?: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                top?: (() => vue.VNodeChild) | undefined;
                headers?: (() => vue.VNodeChild) | undefined;
                bottom?: (() => vue.VNodeChild) | undefined;
            };
            'v-slots'?: {
                [x: `item.${string}`]: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                default?: false | (() => vue.VNodeChild) | undefined;
                item?: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                loading?: false | (() => vue.VNodeChild) | undefined;
                'group-header'?: false | ((args_0: {
                    index: number;
                    item: GroupHeaderItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                    toggleGroup: (group: GroupHeaderItem) => void;
                    isGroupOpen: (group: GroupHeaderItem) => boolean;
                }) => vue.VNodeChild) | undefined;
                'no-data'?: false | (() => vue.VNodeChild) | undefined;
                'expanded-row'?: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                'item.data-table-select'?: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                'item.data-table-expand'?: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                top?: false | (() => vue.VNodeChild) | undefined;
                headers?: false | (() => vue.VNodeChild) | undefined;
                bottom?: false | (() => vue.VNodeChild) | undefined;
            } | undefined;
        } & {
            [x: `v-slot:item.${string}`]: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:default"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:item"?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:loading"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:group-header"?: false | ((args_0: {
                index: number;
                item: GroupHeaderItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
                toggleGroup: (group: GroupHeaderItem) => void;
                isGroupOpen: (group: GroupHeaderItem) => boolean;
            }) => vue.VNodeChild) | undefined;
            "v-slot:no-data"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:expanded-row"?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:item.data-table-select"?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:item.data-table-expand"?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:top"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:headers"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:bottom"?: false | (() => vue.VNodeChild) | undefined;
        } & {
            "onUpdate:modelValue"?: ((value: any[]) => any) | undefined;
            "onUpdate:sortBy"?: ((value: any) => any) | undefined;
            "onUpdate:groupBy"?: ((value: any) => any) | undefined;
            "onUpdate:expanded"?: ((value: any) => any) | undefined;
            "onClick:row"?: ((e: Event, value: {
                item: DataTableItem;
            }) => any) | undefined;
            "onUpdate:options"?: ((value: any) => any) | undefined;
        } & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "style" | "expanded" | "tag" | "sticky" | "headers" | "noDataText" | "loadingText" | "sortBy" | "items" | "density" | "modelValue" | "itemTitle" | "itemValue" | "itemChildren" | "itemProps" | "returnObject" | "hideNoData" | "filterMode" | "noFilter" | "hover" | "fixedHeader" | "fixedFooter" | "itemHeight" | "multiSort" | "mustSort" | "groupBy" | "showSelect" | "sortAscIcon" | "sortDescIcon" | "expandOnClick" | "showExpand" | "visibleItems">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: ((event: "update:modelValue", value: any[]) => void) & ((event: "update:options", value: any) => void) & ((event: "update:sortBy", value: any) => void) & ((event: "update:groupBy", value: any) => void) & ((event: "update:expanded", value: any) => void) & ((event: "click:row", e: Event, value: {
            item: DataTableItem;
        }) => void);
        $el: any;
        $options: vue.ComponentOptionsBase<{
            style: vue.StyleValue;
            expanded: string[];
            tag: string;
            sticky: boolean;
            headers: DataTableHeader[] | DataTableHeader[][];
            noDataText: string;
            loadingText: string;
            sortBy: SortItem[];
            items: any[];
            density: Density;
            modelValue: any[];
            itemTitle: SelectItemKey;
            itemValue: NonNullable<SelectItemKey>;
            itemChildren: SelectItemKey;
            itemProps: SelectItemKey;
            returnObject: boolean;
            hideNoData: boolean;
            filterMode: FilterMode;
            noFilter: boolean;
            hover: boolean;
            fixedHeader: boolean;
            fixedFooter: boolean;
            itemHeight: string | number;
            multiSort: boolean;
            mustSort: boolean;
            groupBy: SortItem[];
            showSelect: boolean;
            sortAscIcon: IconValue;
            sortDescIcon: IconValue;
            expandOnClick: boolean;
            showExpand: boolean;
            visibleItems: string | number;
        } & {
            search?: string | undefined;
            height?: string | number | undefined;
            width?: string | number | undefined;
            color?: string | undefined;
            loading?: string | boolean | undefined;
            class?: any;
            theme?: string | undefined;
            customFilter?: FilterFunction | undefined;
            customKeyFilter?: FilterKeyFunctions | undefined;
            filterKeys?: FilterKeys | undefined;
            rowHeight?: number | undefined;
            'onClick:row'?: ((e: Event, value: {
                item: DataTableItem;
            }) => void) | undefined;
        } & {
            $children?: vue.VNodeChild | (() => vue.VNodeChild) | {
                [x: `item.${string}`]: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                default?: (() => vue.VNodeChild) | undefined;
                item?: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                loading?: (() => vue.VNodeChild) | undefined;
                'group-header'?: ((args_0: {
                    index: number;
                    item: GroupHeaderItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                    toggleGroup: (group: GroupHeaderItem) => void;
                    isGroupOpen: (group: GroupHeaderItem) => boolean;
                }) => vue.VNodeChild) | undefined;
                'no-data'?: (() => vue.VNodeChild) | undefined;
                'expanded-row'?: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                'item.data-table-select'?: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                'item.data-table-expand'?: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                top?: (() => vue.VNodeChild) | undefined;
                headers?: (() => vue.VNodeChild) | undefined;
                bottom?: (() => vue.VNodeChild) | undefined;
            };
            'v-slots'?: {
                [x: `item.${string}`]: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                default?: false | (() => vue.VNodeChild) | undefined;
                item?: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                loading?: false | (() => vue.VNodeChild) | undefined;
                'group-header'?: false | ((args_0: {
                    index: number;
                    item: GroupHeaderItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                    toggleGroup: (group: GroupHeaderItem) => void;
                    isGroupOpen: (group: GroupHeaderItem) => boolean;
                }) => vue.VNodeChild) | undefined;
                'no-data'?: false | (() => vue.VNodeChild) | undefined;
                'expanded-row'?: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                'item.data-table-select'?: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                'item.data-table-expand'?: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                top?: false | (() => vue.VNodeChild) | undefined;
                headers?: false | (() => vue.VNodeChild) | undefined;
                bottom?: false | (() => vue.VNodeChild) | undefined;
            } | undefined;
        } & {
            [x: `v-slot:item.${string}`]: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:default"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:item"?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:loading"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:group-header"?: false | ((args_0: {
                index: number;
                item: GroupHeaderItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
                toggleGroup: (group: GroupHeaderItem) => void;
                isGroupOpen: (group: GroupHeaderItem) => boolean;
            }) => vue.VNodeChild) | undefined;
            "v-slot:no-data"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:expanded-row"?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:item.data-table-select"?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:item.data-table-expand"?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:top"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:headers"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:bottom"?: false | (() => vue.VNodeChild) | undefined;
        } & {
            "onUpdate:modelValue"?: ((value: any[]) => any) | undefined;
            "onUpdate:sortBy"?: ((value: any) => any) | undefined;
            "onUpdate:groupBy"?: ((value: any) => any) | undefined;
            "onUpdate:expanded"?: ((value: any) => any) | undefined;
            "onClick:row"?: ((e: Event, value: {
                item: DataTableItem;
            }) => any) | undefined;
            "onUpdate:options"?: ((value: any) => any) | undefined;
        }, void, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
            'update:modelValue': (value: any[]) => true;
            'update:sortBy': (value: any) => true;
            'update:options': (value: any) => true;
            'update:groupBy': (value: any) => true;
            'update:expanded': (value: any) => true;
            'click:row': (e: Event, value: {
                item: DataTableItem;
            }) => true;
        }, string, {
            style: vue.StyleValue;
            expanded: string[];
            tag: string;
            sticky: boolean;
            headers: DataTableHeader[] | DataTableHeader[][];
            noDataText: string;
            loadingText: string;
            sortBy: SortItem[];
            items: any[];
            density: Density;
            modelValue: any[];
            itemTitle: SelectItemKey;
            itemValue: NonNullable<SelectItemKey>;
            itemChildren: SelectItemKey;
            itemProps: SelectItemKey;
            returnObject: boolean;
            hideNoData: boolean;
            filterMode: FilterMode;
            noFilter: boolean;
            hover: boolean;
            fixedHeader: boolean;
            fixedFooter: boolean;
            itemHeight: string | number;
            multiSort: boolean;
            mustSort: boolean;
            groupBy: SortItem[];
            showSelect: boolean;
            sortAscIcon: IconValue;
            sortDescIcon: IconValue;
            expandOnClick: boolean;
            showExpand: boolean;
            visibleItems: string | number;
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & {
        style: vue.StyleValue;
        expanded: string[];
        tag: string;
        sticky: boolean;
        headers: DataTableHeader[] | DataTableHeader[][];
        noDataText: string;
        loadingText: string;
        sortBy: SortItem[];
        items: any[];
        density: Density;
        modelValue: any[];
        itemTitle: SelectItemKey;
        itemValue: NonNullable<SelectItemKey>;
        itemChildren: SelectItemKey;
        itemProps: SelectItemKey;
        returnObject: boolean;
        hideNoData: boolean;
        filterMode: FilterMode;
        noFilter: boolean;
        hover: boolean;
        fixedHeader: boolean;
        fixedFooter: boolean;
        itemHeight: string | number;
        multiSort: boolean;
        mustSort: boolean;
        groupBy: SortItem[];
        showSelect: boolean;
        sortAscIcon: IconValue;
        sortDescIcon: IconValue;
        expandOnClick: boolean;
        showExpand: boolean;
        visibleItems: string | number;
    } & {
        search?: string | undefined;
        height?: string | number | undefined;
        width?: string | number | undefined;
        color?: string | undefined;
        loading?: string | boolean | undefined;
        class?: any;
        theme?: string | undefined;
        customFilter?: FilterFunction | undefined;
        customKeyFilter?: FilterKeyFunctions | undefined;
        filterKeys?: FilterKeys | undefined;
        rowHeight?: number | undefined;
        'onClick:row'?: ((e: Event, value: {
            item: DataTableItem;
        }) => void) | undefined;
    } & {
        $children?: vue.VNodeChild | (() => vue.VNodeChild) | {
            [x: `item.${string}`]: ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            default?: (() => vue.VNodeChild) | undefined;
            item?: ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            loading?: (() => vue.VNodeChild) | undefined;
            'group-header'?: ((args_0: {
                index: number;
                item: GroupHeaderItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
                toggleGroup: (group: GroupHeaderItem) => void;
                isGroupOpen: (group: GroupHeaderItem) => boolean;
            }) => vue.VNodeChild) | undefined;
            'no-data'?: (() => vue.VNodeChild) | undefined;
            'expanded-row'?: ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            'item.data-table-select'?: ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            'item.data-table-expand'?: ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            top?: (() => vue.VNodeChild) | undefined;
            headers?: (() => vue.VNodeChild) | undefined;
            bottom?: (() => vue.VNodeChild) | undefined;
        };
        'v-slots'?: {
            [x: `item.${string}`]: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            default?: false | (() => vue.VNodeChild) | undefined;
            item?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            loading?: false | (() => vue.VNodeChild) | undefined;
            'group-header'?: false | ((args_0: {
                index: number;
                item: GroupHeaderItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
                toggleGroup: (group: GroupHeaderItem) => void;
                isGroupOpen: (group: GroupHeaderItem) => boolean;
            }) => vue.VNodeChild) | undefined;
            'no-data'?: false | (() => vue.VNodeChild) | undefined;
            'expanded-row'?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            'item.data-table-select'?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            'item.data-table-expand'?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            top?: false | (() => vue.VNodeChild) | undefined;
            headers?: false | (() => vue.VNodeChild) | undefined;
            bottom?: false | (() => vue.VNodeChild) | undefined;
        } | undefined;
    } & {
        [x: `v-slot:item.${string}`]: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        "v-slot:default"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:item"?: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        "v-slot:loading"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:group-header"?: false | ((args_0: {
            index: number;
            item: GroupHeaderItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
            toggleGroup: (group: GroupHeaderItem) => void;
            isGroupOpen: (group: GroupHeaderItem) => boolean;
        }) => vue.VNodeChild) | undefined;
        "v-slot:no-data"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:expanded-row"?: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        "v-slot:item.data-table-select"?: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        "v-slot:item.data-table-expand"?: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        "v-slot:top"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:headers"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:bottom"?: false | (() => vue.VNodeChild) | undefined;
    } & {
        "onUpdate:modelValue"?: ((value: any[]) => any) | undefined;
        "onUpdate:sortBy"?: ((value: any) => any) | undefined;
        "onUpdate:groupBy"?: ((value: any) => any) | undefined;
        "onUpdate:expanded"?: ((value: any) => any) | undefined;
        "onClick:row"?: ((e: Event, value: {
            item: DataTableItem;
        }) => any) | undefined;
        "onUpdate:options"?: ((value: any) => any) | undefined;
    } & vue.ShallowUnwrapRef<{}> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<{
    style: vue.StyleValue;
    expanded: string[];
    tag: string;
    sticky: boolean;
    headers: DataTableHeader[] | DataTableHeader[][];
    noDataText: string;
    loadingText: string;
    sortBy: SortItem[];
    items: any[];
    density: Density;
    modelValue: any[];
    itemTitle: SelectItemKey;
    itemValue: NonNullable<SelectItemKey>;
    itemChildren: SelectItemKey;
    itemProps: SelectItemKey;
    returnObject: boolean;
    hideNoData: boolean;
    filterMode: FilterMode;
    noFilter: boolean;
    hover: boolean;
    fixedHeader: boolean;
    fixedFooter: boolean;
    itemHeight: string | number;
    multiSort: boolean;
    mustSort: boolean;
    groupBy: SortItem[];
    showSelect: boolean;
    sortAscIcon: IconValue;
    sortDescIcon: IconValue;
    expandOnClick: boolean;
    showExpand: boolean;
    visibleItems: string | number;
} & {
    search?: string | undefined;
    height?: string | number | undefined;
    width?: string | number | undefined;
    color?: string | undefined;
    loading?: string | boolean | undefined;
    class?: any;
    theme?: string | undefined;
    customFilter?: FilterFunction | undefined;
    customKeyFilter?: FilterKeyFunctions | undefined;
    filterKeys?: FilterKeys | undefined;
    rowHeight?: number | undefined;
    'onClick:row'?: ((e: Event, value: {
        item: DataTableItem;
    }) => void) | undefined;
} & {
    $children?: vue.VNodeChild | (() => vue.VNodeChild) | {
        [x: `item.${string}`]: ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        default?: (() => vue.VNodeChild) | undefined;
        item?: ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        loading?: (() => vue.VNodeChild) | undefined;
        'group-header'?: ((args_0: {
            index: number;
            item: GroupHeaderItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
            toggleGroup: (group: GroupHeaderItem) => void;
            isGroupOpen: (group: GroupHeaderItem) => boolean;
        }) => vue.VNodeChild) | undefined;
        'no-data'?: (() => vue.VNodeChild) | undefined;
        'expanded-row'?: ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        'item.data-table-select'?: ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        'item.data-table-expand'?: ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        top?: (() => vue.VNodeChild) | undefined;
        headers?: (() => vue.VNodeChild) | undefined;
        bottom?: (() => vue.VNodeChild) | undefined;
    };
    'v-slots'?: {
        [x: `item.${string}`]: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        default?: false | (() => vue.VNodeChild) | undefined;
        item?: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        loading?: false | (() => vue.VNodeChild) | undefined;
        'group-header'?: false | ((args_0: {
            index: number;
            item: GroupHeaderItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
            toggleGroup: (group: GroupHeaderItem) => void;
            isGroupOpen: (group: GroupHeaderItem) => boolean;
        }) => vue.VNodeChild) | undefined;
        'no-data'?: false | (() => vue.VNodeChild) | undefined;
        'expanded-row'?: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        'item.data-table-select'?: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        'item.data-table-expand'?: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        top?: false | (() => vue.VNodeChild) | undefined;
        headers?: false | (() => vue.VNodeChild) | undefined;
        bottom?: false | (() => vue.VNodeChild) | undefined;
    } | undefined;
} & {
    [x: `v-slot:item.${string}`]: false | ((args_0: {
        index: number;
        item: DataTableItem;
        columns: InternalDataTableHeader[];
        isExpanded: (item: DataTableItem) => boolean;
        toggleExpand: (item: DataTableItem) => void;
        isSelected: (items: DataTableItem[]) => boolean;
        toggleSelect: (item: DataTableItem) => void;
    }) => vue.VNodeChild) | undefined;
    "v-slot:default"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:item"?: false | ((args_0: {
        index: number;
        item: DataTableItem;
        columns: InternalDataTableHeader[];
        isExpanded: (item: DataTableItem) => boolean;
        toggleExpand: (item: DataTableItem) => void;
        isSelected: (items: DataTableItem[]) => boolean;
        toggleSelect: (item: DataTableItem) => void;
    }) => vue.VNodeChild) | undefined;
    "v-slot:loading"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:group-header"?: false | ((args_0: {
        index: number;
        item: GroupHeaderItem;
        columns: InternalDataTableHeader[];
        isExpanded: (item: DataTableItem) => boolean;
        toggleExpand: (item: DataTableItem) => void;
        isSelected: (items: DataTableItem[]) => boolean;
        toggleSelect: (item: DataTableItem) => void;
        toggleGroup: (group: GroupHeaderItem) => void;
        isGroupOpen: (group: GroupHeaderItem) => boolean;
    }) => vue.VNodeChild) | undefined;
    "v-slot:no-data"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:expanded-row"?: false | ((args_0: {
        index: number;
        item: DataTableItem;
        columns: InternalDataTableHeader[];
        isExpanded: (item: DataTableItem) => boolean;
        toggleExpand: (item: DataTableItem) => void;
        isSelected: (items: DataTableItem[]) => boolean;
        toggleSelect: (item: DataTableItem) => void;
    }) => vue.VNodeChild) | undefined;
    "v-slot:item.data-table-select"?: false | ((args_0: {
        index: number;
        item: DataTableItem;
        columns: InternalDataTableHeader[];
        isExpanded: (item: DataTableItem) => boolean;
        toggleExpand: (item: DataTableItem) => void;
        isSelected: (items: DataTableItem[]) => boolean;
        toggleSelect: (item: DataTableItem) => void;
    }) => vue.VNodeChild) | undefined;
    "v-slot:item.data-table-expand"?: false | ((args_0: {
        index: number;
        item: DataTableItem;
        columns: InternalDataTableHeader[];
        isExpanded: (item: DataTableItem) => boolean;
        toggleExpand: (item: DataTableItem) => void;
        isSelected: (items: DataTableItem[]) => boolean;
        toggleSelect: (item: DataTableItem) => void;
    }) => vue.VNodeChild) | undefined;
    "v-slot:top"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:headers"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:bottom"?: false | (() => vue.VNodeChild) | undefined;
} & {
    "onUpdate:modelValue"?: ((value: any[]) => any) | undefined;
    "onUpdate:sortBy"?: ((value: any) => any) | undefined;
    "onUpdate:groupBy"?: ((value: any) => any) | undefined;
    "onUpdate:expanded"?: ((value: any) => any) | undefined;
    "onClick:row"?: ((e: Event, value: {
        item: DataTableItem;
    }) => any) | undefined;
    "onUpdate:options"?: ((value: any) => any) | undefined;
}, void, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (value: any[]) => true;
    'update:sortBy': (value: any) => true;
    'update:options': (value: any) => true;
    'update:groupBy': (value: any) => true;
    'update:expanded': (value: any) => true;
    'click:row': (e: Event, value: {
        item: DataTableItem;
    }) => true;
}, string, {
    style: vue.StyleValue;
    expanded: string[];
    tag: string;
    sticky: boolean;
    headers: DataTableHeader[] | DataTableHeader[][];
    noDataText: string;
    loadingText: string;
    sortBy: SortItem[];
    items: any[];
    density: Density;
    modelValue: any[];
    itemTitle: SelectItemKey;
    itemValue: NonNullable<SelectItemKey>;
    itemChildren: SelectItemKey;
    itemProps: SelectItemKey;
    returnObject: boolean;
    hideNoData: boolean;
    filterMode: FilterMode;
    noFilter: boolean;
    hover: boolean;
    fixedHeader: boolean;
    fixedFooter: boolean;
    itemHeight: string | number;
    multiSort: boolean;
    mustSort: boolean;
    groupBy: SortItem[];
    showSelect: boolean;
    sortAscIcon: IconValue;
    sortDescIcon: IconValue;
    expandOnClick: boolean;
    showExpand: boolean;
    visibleItems: string | number;
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & FilterPropsOptions<{
    customFilter: vue.PropType<FilterFunction>;
    customKeyFilter: vue.PropType<FilterKeyFunctions>;
    filterKeys: vue.PropType<FilterKeys>;
    filterMode: {
        type: vue.PropType<FilterMode>;
        default: string;
    };
    noFilter: BooleanConstructor;
    visibleItems: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    itemHeight: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    density: {
        type: vue.PropType<Density>;
        default: string;
        validator: (v: any) => boolean;
    };
    class: vue.PropType<any>;
    style: {
        type: vue.PropType<vue.StyleValue>;
        default: null;
    };
    fixedHeader: BooleanConstructor;
    fixedFooter: BooleanConstructor;
    height: (StringConstructor | NumberConstructor)[];
    hover: BooleanConstructor;
    loading: (StringConstructor | BooleanConstructor)[];
    color: StringConstructor;
    sticky: BooleanConstructor;
    multiSort: BooleanConstructor;
    sortAscIcon: {
        type: vue.PropType<IconValue>;
        default: string;
    };
    sortDescIcon: {
        type: vue.PropType<IconValue>;
        default: string;
    };
    sortBy: {
        type: vue.PropType<SortItem[]>;
        default: () => never[];
    };
    mustSort: BooleanConstructor;
    showSelect: BooleanConstructor;
    modelValue: {
        type: vue.PropType<any[]>;
        default: () => never[];
    };
    items: {
        type: vue.PropType<any[]>;
        default: () => never[];
    };
    itemTitle: {
        type: vue.PropType<SelectItemKey>;
        default: string;
    };
    itemValue: Omit<{
        type: vue.PropType<SelectItemKey>;
        default: string;
    }, "type" | "default"> & {
        type: vue.PropType<NonNullable<SelectItemKey>>;
        default: NonNullable<SelectItemKey>;
    };
    itemChildren: {
        type: vue.PropType<SelectItemKey>;
        default: string;
    };
    itemProps: {
        type: vue.PropType<SelectItemKey>;
        default: string;
    };
    returnObject: BooleanConstructor;
    headers: {
        type: vue.PropType<DataTableHeader[] | DataTableHeader[][]>;
        default: () => never[];
    };
    groupBy: {
        type: vue.PropType<SortItem[]>;
        default: () => never[];
    };
    expandOnClick: BooleanConstructor;
    showExpand: BooleanConstructor;
    expanded: {
        type: vue.PropType<string[]>;
        default: () => never[];
    };
    width: (StringConstructor | NumberConstructor)[];
    search: StringConstructor;
    loadingText: {
        type: StringConstructor;
        default: string;
    };
    hideNoData: BooleanConstructor;
    noDataText: {
        type: StringConstructor;
        default: string;
    };
    rowHeight: NumberConstructor;
    'onClick:row': vue.PropType<(e: Event, value: {
        item: DataTableItem;
    }) => void>;
}, vue.ExtractPropTypes<{
    customFilter: vue.PropType<FilterFunction>;
    customKeyFilter: vue.PropType<FilterKeyFunctions>;
    filterKeys: vue.PropType<FilterKeys>;
    filterMode: {
        type: vue.PropType<FilterMode>;
        default: string;
    };
    noFilter: BooleanConstructor;
    visibleItems: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    itemHeight: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    density: {
        type: vue.PropType<Density>;
        default: string;
        validator: (v: any) => boolean;
    };
    class: vue.PropType<any>;
    style: {
        type: vue.PropType<vue.StyleValue>;
        default: null;
    };
    fixedHeader: BooleanConstructor;
    fixedFooter: BooleanConstructor;
    height: (StringConstructor | NumberConstructor)[];
    hover: BooleanConstructor;
    loading: (StringConstructor | BooleanConstructor)[];
    color: StringConstructor;
    sticky: BooleanConstructor;
    multiSort: BooleanConstructor;
    sortAscIcon: {
        type: vue.PropType<IconValue>;
        default: string;
    };
    sortDescIcon: {
        type: vue.PropType<IconValue>;
        default: string;
    };
    sortBy: {
        type: vue.PropType<SortItem[]>;
        default: () => never[];
    };
    mustSort: BooleanConstructor;
    showSelect: BooleanConstructor;
    modelValue: {
        type: vue.PropType<any[]>;
        default: () => never[];
    };
    items: {
        type: vue.PropType<any[]>;
        default: () => never[];
    };
    itemTitle: {
        type: vue.PropType<SelectItemKey>;
        default: string;
    };
    itemValue: Omit<{
        type: vue.PropType<SelectItemKey>;
        default: string;
    }, "type" | "default"> & {
        type: vue.PropType<NonNullable<SelectItemKey>>;
        default: NonNullable<SelectItemKey>;
    };
    itemChildren: {
        type: vue.PropType<SelectItemKey>;
        default: string;
    };
    itemProps: {
        type: vue.PropType<SelectItemKey>;
        default: string;
    };
    returnObject: BooleanConstructor;
    headers: {
        type: vue.PropType<DataTableHeader[] | DataTableHeader[][]>;
        default: () => never[];
    };
    groupBy: {
        type: vue.PropType<SortItem[]>;
        default: () => never[];
    };
    expandOnClick: BooleanConstructor;
    showExpand: BooleanConstructor;
    expanded: {
        type: vue.PropType<string[]>;
        default: () => never[];
    };
    width: (StringConstructor | NumberConstructor)[];
    search: StringConstructor;
    loadingText: {
        type: StringConstructor;
        default: string;
    };
    hideNoData: BooleanConstructor;
    noDataText: {
        type: StringConstructor;
        default: string;
    };
    rowHeight: NumberConstructor;
    'onClick:row': vue.PropType<(e: Event, value: {
        item: DataTableItem;
    }) => void>;
}>>;
type VDataTableVirtual = InstanceType<typeof VDataTableVirtual>;

declare const VDataTableServer: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            style: vue.StyleValue;
            expanded: string[];
            tag: string;
            page: string | number;
            sticky: boolean;
            headers: DataTableHeader[] | DataTableHeader[][];
            noDataText: string;
            loadingText: string;
            itemsPerPageText: string;
            sortBy: SortItem[];
            pageText: string;
            items: any[];
            density: Density;
            modelValue: any[];
            itemTitle: SelectItemKey;
            itemValue: NonNullable<SelectItemKey>;
            itemChildren: SelectItemKey;
            itemProps: SelectItemKey;
            returnObject: boolean;
            hideNoData: boolean;
            hover: boolean;
            nextIcon: string;
            prevIcon: string;
            firstIcon: string;
            lastIcon: string;
            fixedHeader: boolean;
            fixedFooter: boolean;
            itemsPerPage: string | number;
            firstPageLabel: string;
            prevPageLabel: string;
            nextPageLabel: string;
            lastPageLabel: string;
            itemsPerPageOptions: {
                title: string;
                value: number;
            }[];
            showCurrentPage: boolean;
            multiSort: boolean;
            mustSort: boolean;
            groupBy: SortItem[];
            showSelect: boolean;
            sortAscIcon: IconValue;
            sortDescIcon: IconValue;
            expandOnClick: boolean;
            showExpand: boolean;
        }> & Omit<{
            style: vue.StyleValue;
            expanded: string[];
            tag: string;
            page: string | number;
            sticky: boolean;
            headers: DataTableHeader[] | DataTableHeader[][];
            noDataText: string;
            loadingText: string;
            itemsPerPageText: string;
            sortBy: SortItem[];
            pageText: string;
            items: any[];
            density: Density;
            modelValue: any[];
            itemTitle: SelectItemKey;
            itemValue: NonNullable<SelectItemKey>;
            itemChildren: SelectItemKey;
            itemProps: SelectItemKey;
            returnObject: boolean;
            hideNoData: boolean;
            hover: boolean;
            nextIcon: string;
            prevIcon: string;
            firstIcon: string;
            lastIcon: string;
            fixedHeader: boolean;
            fixedFooter: boolean;
            itemsPerPage: string | number;
            itemsLength: string | number;
            firstPageLabel: string;
            prevPageLabel: string;
            nextPageLabel: string;
            lastPageLabel: string;
            itemsPerPageOptions: {
                title: string;
                value: number;
            }[];
            showCurrentPage: boolean;
            multiSort: boolean;
            mustSort: boolean;
            groupBy: SortItem[];
            showSelect: boolean;
            sortAscIcon: IconValue;
            sortDescIcon: IconValue;
            expandOnClick: boolean;
            showExpand: boolean;
        } & {
            search?: string | undefined;
            height?: string | number | undefined;
            width?: string | number | undefined;
            color?: string | undefined;
            loading?: string | boolean | undefined;
            class?: any;
            theme?: string | undefined;
            rowHeight?: number | undefined;
            'onClick:row'?: ((e: Event, value: {
                item: DataTableItem;
            }) => void) | undefined;
        } & {
            $children?: vue.VNodeChild | (() => vue.VNodeChild) | {
                [x: `item.${string}`]: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                default?: (() => vue.VNodeChild) | undefined;
                item?: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                loading?: (() => vue.VNodeChild) | undefined;
                'group-header'?: ((args_0: {
                    index: number;
                    item: GroupHeaderItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                    toggleGroup: (group: GroupHeaderItem) => void;
                    isGroupOpen: (group: GroupHeaderItem) => boolean;
                }) => vue.VNodeChild) | undefined;
                'no-data'?: (() => vue.VNodeChild) | undefined;
                'expanded-row'?: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                'item.data-table-select'?: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                'item.data-table-expand'?: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                colgroup?: ((args_0: InternalDataTableHeader) => vue.VNodeChild) | undefined;
                top?: (() => vue.VNodeChild) | undefined;
                headers?: (() => vue.VNodeChild) | undefined;
                body?: (() => vue.VNodeChild) | undefined;
                tbody?: (() => vue.VNodeChild) | undefined;
                thead?: (() => vue.VNodeChild) | undefined;
                tfoot?: (() => vue.VNodeChild) | undefined;
                bottom?: (() => vue.VNodeChild) | undefined;
                'footer.prepend'?: (() => vue.VNodeChild) | undefined;
            };
            'v-slots'?: {
                [x: `item.${string}`]: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                default?: false | (() => vue.VNodeChild) | undefined;
                item?: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                loading?: false | (() => vue.VNodeChild) | undefined;
                'group-header'?: false | ((args_0: {
                    index: number;
                    item: GroupHeaderItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                    toggleGroup: (group: GroupHeaderItem) => void;
                    isGroupOpen: (group: GroupHeaderItem) => boolean;
                }) => vue.VNodeChild) | undefined;
                'no-data'?: false | (() => vue.VNodeChild) | undefined;
                'expanded-row'?: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                'item.data-table-select'?: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                'item.data-table-expand'?: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                colgroup?: false | ((args_0: InternalDataTableHeader) => vue.VNodeChild) | undefined;
                top?: false | (() => vue.VNodeChild) | undefined;
                headers?: false | (() => vue.VNodeChild) | undefined;
                body?: false | (() => vue.VNodeChild) | undefined;
                tbody?: false | (() => vue.VNodeChild) | undefined;
                thead?: false | (() => vue.VNodeChild) | undefined;
                tfoot?: false | (() => vue.VNodeChild) | undefined;
                bottom?: false | (() => vue.VNodeChild) | undefined;
                'footer.prepend'?: false | (() => vue.VNodeChild) | undefined;
            } | undefined;
        } & {
            [x: `v-slot:item.${string}`]: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:default"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:item"?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:loading"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:group-header"?: false | ((args_0: {
                index: number;
                item: GroupHeaderItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
                toggleGroup: (group: GroupHeaderItem) => void;
                isGroupOpen: (group: GroupHeaderItem) => boolean;
            }) => vue.VNodeChild) | undefined;
            "v-slot:no-data"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:expanded-row"?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:item.data-table-select"?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:item.data-table-expand"?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:colgroup"?: false | ((args_0: InternalDataTableHeader) => vue.VNodeChild) | undefined;
            "v-slot:top"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:headers"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:body"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:tbody"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:thead"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:tfoot"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:bottom"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:footer.prepend"?: false | (() => vue.VNodeChild) | undefined;
        } & {
            "onUpdate:modelValue"?: ((value: any[]) => any) | undefined;
            "onUpdate:page"?: ((page: number) => any) | undefined;
            "onUpdate:itemsPerPage"?: ((page: number) => any) | undefined;
            "onUpdate:sortBy"?: ((sortBy: any) => any) | undefined;
            "onUpdate:groupBy"?: ((value: any) => any) | undefined;
            "onUpdate:expanded"?: ((options: any) => any) | undefined;
            "onClick:row"?: ((e: Event, value: {
                item: DataTableItem;
            }) => any) | undefined;
            "onUpdate:options"?: ((options: any) => any) | undefined;
        } & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "style" | "expanded" | "tag" | "page" | "sticky" | "headers" | "noDataText" | "loadingText" | "itemsPerPageText" | "sortBy" | "pageText" | "items" | "density" | "modelValue" | "itemTitle" | "itemValue" | "itemChildren" | "itemProps" | "returnObject" | "hideNoData" | "hover" | "nextIcon" | "prevIcon" | "firstIcon" | "lastIcon" | "fixedHeader" | "fixedFooter" | "itemsPerPage" | "firstPageLabel" | "prevPageLabel" | "nextPageLabel" | "lastPageLabel" | "itemsPerPageOptions" | "showCurrentPage" | "multiSort" | "mustSort" | "groupBy" | "showSelect" | "sortAscIcon" | "sortDescIcon" | "expandOnClick" | "showExpand">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: ((event: "update:modelValue", value: any[]) => void) & ((event: "update:options", options: any) => void) & ((event: "update:page", page: number) => void) & ((event: "update:itemsPerPage", page: number) => void) & ((event: "update:sortBy", sortBy: any) => void) & ((event: "update:groupBy", value: any) => void) & ((event: "update:expanded", options: any) => void) & ((event: "click:row", e: Event, value: {
            item: DataTableItem;
        }) => void);
        $el: any;
        $options: vue.ComponentOptionsBase<{
            style: vue.StyleValue;
            expanded: string[];
            tag: string;
            page: string | number;
            sticky: boolean;
            headers: DataTableHeader[] | DataTableHeader[][];
            noDataText: string;
            loadingText: string;
            itemsPerPageText: string;
            sortBy: SortItem[];
            pageText: string;
            items: any[];
            density: Density;
            modelValue: any[];
            itemTitle: SelectItemKey;
            itemValue: NonNullable<SelectItemKey>;
            itemChildren: SelectItemKey;
            itemProps: SelectItemKey;
            returnObject: boolean;
            hideNoData: boolean;
            hover: boolean;
            nextIcon: string;
            prevIcon: string;
            firstIcon: string;
            lastIcon: string;
            fixedHeader: boolean;
            fixedFooter: boolean;
            itemsPerPage: string | number;
            itemsLength: string | number;
            firstPageLabel: string;
            prevPageLabel: string;
            nextPageLabel: string;
            lastPageLabel: string;
            itemsPerPageOptions: {
                title: string;
                value: number;
            }[];
            showCurrentPage: boolean;
            multiSort: boolean;
            mustSort: boolean;
            groupBy: SortItem[];
            showSelect: boolean;
            sortAscIcon: IconValue;
            sortDescIcon: IconValue;
            expandOnClick: boolean;
            showExpand: boolean;
        } & {
            search?: string | undefined;
            height?: string | number | undefined;
            width?: string | number | undefined;
            color?: string | undefined;
            loading?: string | boolean | undefined;
            class?: any;
            theme?: string | undefined;
            rowHeight?: number | undefined;
            'onClick:row'?: ((e: Event, value: {
                item: DataTableItem;
            }) => void) | undefined;
        } & {
            $children?: vue.VNodeChild | (() => vue.VNodeChild) | {
                [x: `item.${string}`]: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                default?: (() => vue.VNodeChild) | undefined;
                item?: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                loading?: (() => vue.VNodeChild) | undefined;
                'group-header'?: ((args_0: {
                    index: number;
                    item: GroupHeaderItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                    toggleGroup: (group: GroupHeaderItem) => void;
                    isGroupOpen: (group: GroupHeaderItem) => boolean;
                }) => vue.VNodeChild) | undefined;
                'no-data'?: (() => vue.VNodeChild) | undefined;
                'expanded-row'?: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                'item.data-table-select'?: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                'item.data-table-expand'?: ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                colgroup?: ((args_0: InternalDataTableHeader) => vue.VNodeChild) | undefined;
                top?: (() => vue.VNodeChild) | undefined;
                headers?: (() => vue.VNodeChild) | undefined;
                body?: (() => vue.VNodeChild) | undefined;
                tbody?: (() => vue.VNodeChild) | undefined;
                thead?: (() => vue.VNodeChild) | undefined;
                tfoot?: (() => vue.VNodeChild) | undefined;
                bottom?: (() => vue.VNodeChild) | undefined;
                'footer.prepend'?: (() => vue.VNodeChild) | undefined;
            };
            'v-slots'?: {
                [x: `item.${string}`]: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                default?: false | (() => vue.VNodeChild) | undefined;
                item?: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                loading?: false | (() => vue.VNodeChild) | undefined;
                'group-header'?: false | ((args_0: {
                    index: number;
                    item: GroupHeaderItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                    toggleGroup: (group: GroupHeaderItem) => void;
                    isGroupOpen: (group: GroupHeaderItem) => boolean;
                }) => vue.VNodeChild) | undefined;
                'no-data'?: false | (() => vue.VNodeChild) | undefined;
                'expanded-row'?: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                'item.data-table-select'?: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                'item.data-table-expand'?: false | ((args_0: {
                    index: number;
                    item: DataTableItem;
                    columns: InternalDataTableHeader[];
                    isExpanded: (item: DataTableItem) => boolean;
                    toggleExpand: (item: DataTableItem) => void;
                    isSelected: (items: DataTableItem[]) => boolean;
                    toggleSelect: (item: DataTableItem) => void;
                }) => vue.VNodeChild) | undefined;
                colgroup?: false | ((args_0: InternalDataTableHeader) => vue.VNodeChild) | undefined;
                top?: false | (() => vue.VNodeChild) | undefined;
                headers?: false | (() => vue.VNodeChild) | undefined;
                body?: false | (() => vue.VNodeChild) | undefined;
                tbody?: false | (() => vue.VNodeChild) | undefined;
                thead?: false | (() => vue.VNodeChild) | undefined;
                tfoot?: false | (() => vue.VNodeChild) | undefined;
                bottom?: false | (() => vue.VNodeChild) | undefined;
                'footer.prepend'?: false | (() => vue.VNodeChild) | undefined;
            } | undefined;
        } & {
            [x: `v-slot:item.${string}`]: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:default"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:item"?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:loading"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:group-header"?: false | ((args_0: {
                index: number;
                item: GroupHeaderItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
                toggleGroup: (group: GroupHeaderItem) => void;
                isGroupOpen: (group: GroupHeaderItem) => boolean;
            }) => vue.VNodeChild) | undefined;
            "v-slot:no-data"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:expanded-row"?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:item.data-table-select"?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:item.data-table-expand"?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            "v-slot:colgroup"?: false | ((args_0: InternalDataTableHeader) => vue.VNodeChild) | undefined;
            "v-slot:top"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:headers"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:body"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:tbody"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:thead"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:tfoot"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:bottom"?: false | (() => vue.VNodeChild) | undefined;
            "v-slot:footer.prepend"?: false | (() => vue.VNodeChild) | undefined;
        } & {
            "onUpdate:modelValue"?: ((value: any[]) => any) | undefined;
            "onUpdate:page"?: ((page: number) => any) | undefined;
            "onUpdate:itemsPerPage"?: ((page: number) => any) | undefined;
            "onUpdate:sortBy"?: ((sortBy: any) => any) | undefined;
            "onUpdate:groupBy"?: ((value: any) => any) | undefined;
            "onUpdate:expanded"?: ((options: any) => any) | undefined;
            "onClick:row"?: ((e: Event, value: {
                item: DataTableItem;
            }) => any) | undefined;
            "onUpdate:options"?: ((options: any) => any) | undefined;
        }, void, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
            'update:modelValue': (value: any[]) => true;
            'update:page': (page: number) => true;
            'update:itemsPerPage': (page: number) => true;
            'update:sortBy': (sortBy: any) => true;
            'update:options': (options: any) => true;
            'update:expanded': (options: any) => true;
            'update:groupBy': (value: any) => true;
            'click:row': (e: Event, value: {
                item: DataTableItem;
            }) => true;
        }, string, {
            style: vue.StyleValue;
            expanded: string[];
            tag: string;
            page: string | number;
            sticky: boolean;
            headers: DataTableHeader[] | DataTableHeader[][];
            noDataText: string;
            loadingText: string;
            itemsPerPageText: string;
            sortBy: SortItem[];
            pageText: string;
            items: any[];
            density: Density;
            modelValue: any[];
            itemTitle: SelectItemKey;
            itemValue: NonNullable<SelectItemKey>;
            itemChildren: SelectItemKey;
            itemProps: SelectItemKey;
            returnObject: boolean;
            hideNoData: boolean;
            hover: boolean;
            nextIcon: string;
            prevIcon: string;
            firstIcon: string;
            lastIcon: string;
            fixedHeader: boolean;
            fixedFooter: boolean;
            itemsPerPage: string | number;
            firstPageLabel: string;
            prevPageLabel: string;
            nextPageLabel: string;
            lastPageLabel: string;
            itemsPerPageOptions: {
                title: string;
                value: number;
            }[];
            showCurrentPage: boolean;
            multiSort: boolean;
            mustSort: boolean;
            groupBy: SortItem[];
            showSelect: boolean;
            sortAscIcon: IconValue;
            sortDescIcon: IconValue;
            expandOnClick: boolean;
            showExpand: boolean;
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & {
        style: vue.StyleValue;
        expanded: string[];
        tag: string;
        page: string | number;
        sticky: boolean;
        headers: DataTableHeader[] | DataTableHeader[][];
        noDataText: string;
        loadingText: string;
        itemsPerPageText: string;
        sortBy: SortItem[];
        pageText: string;
        items: any[];
        density: Density;
        modelValue: any[];
        itemTitle: SelectItemKey;
        itemValue: NonNullable<SelectItemKey>;
        itemChildren: SelectItemKey;
        itemProps: SelectItemKey;
        returnObject: boolean;
        hideNoData: boolean;
        hover: boolean;
        nextIcon: string;
        prevIcon: string;
        firstIcon: string;
        lastIcon: string;
        fixedHeader: boolean;
        fixedFooter: boolean;
        itemsPerPage: string | number;
        itemsLength: string | number;
        firstPageLabel: string;
        prevPageLabel: string;
        nextPageLabel: string;
        lastPageLabel: string;
        itemsPerPageOptions: {
            title: string;
            value: number;
        }[];
        showCurrentPage: boolean;
        multiSort: boolean;
        mustSort: boolean;
        groupBy: SortItem[];
        showSelect: boolean;
        sortAscIcon: IconValue;
        sortDescIcon: IconValue;
        expandOnClick: boolean;
        showExpand: boolean;
    } & {
        search?: string | undefined;
        height?: string | number | undefined;
        width?: string | number | undefined;
        color?: string | undefined;
        loading?: string | boolean | undefined;
        class?: any;
        theme?: string | undefined;
        rowHeight?: number | undefined;
        'onClick:row'?: ((e: Event, value: {
            item: DataTableItem;
        }) => void) | undefined;
    } & {
        $children?: vue.VNodeChild | (() => vue.VNodeChild) | {
            [x: `item.${string}`]: ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            default?: (() => vue.VNodeChild) | undefined;
            item?: ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            loading?: (() => vue.VNodeChild) | undefined;
            'group-header'?: ((args_0: {
                index: number;
                item: GroupHeaderItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
                toggleGroup: (group: GroupHeaderItem) => void;
                isGroupOpen: (group: GroupHeaderItem) => boolean;
            }) => vue.VNodeChild) | undefined;
            'no-data'?: (() => vue.VNodeChild) | undefined;
            'expanded-row'?: ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            'item.data-table-select'?: ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            'item.data-table-expand'?: ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            colgroup?: ((args_0: InternalDataTableHeader) => vue.VNodeChild) | undefined;
            top?: (() => vue.VNodeChild) | undefined;
            headers?: (() => vue.VNodeChild) | undefined;
            body?: (() => vue.VNodeChild) | undefined;
            tbody?: (() => vue.VNodeChild) | undefined;
            thead?: (() => vue.VNodeChild) | undefined;
            tfoot?: (() => vue.VNodeChild) | undefined;
            bottom?: (() => vue.VNodeChild) | undefined;
            'footer.prepend'?: (() => vue.VNodeChild) | undefined;
        };
        'v-slots'?: {
            [x: `item.${string}`]: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            default?: false | (() => vue.VNodeChild) | undefined;
            item?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            loading?: false | (() => vue.VNodeChild) | undefined;
            'group-header'?: false | ((args_0: {
                index: number;
                item: GroupHeaderItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
                toggleGroup: (group: GroupHeaderItem) => void;
                isGroupOpen: (group: GroupHeaderItem) => boolean;
            }) => vue.VNodeChild) | undefined;
            'no-data'?: false | (() => vue.VNodeChild) | undefined;
            'expanded-row'?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            'item.data-table-select'?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            'item.data-table-expand'?: false | ((args_0: {
                index: number;
                item: DataTableItem;
                columns: InternalDataTableHeader[];
                isExpanded: (item: DataTableItem) => boolean;
                toggleExpand: (item: DataTableItem) => void;
                isSelected: (items: DataTableItem[]) => boolean;
                toggleSelect: (item: DataTableItem) => void;
            }) => vue.VNodeChild) | undefined;
            colgroup?: false | ((args_0: InternalDataTableHeader) => vue.VNodeChild) | undefined;
            top?: false | (() => vue.VNodeChild) | undefined;
            headers?: false | (() => vue.VNodeChild) | undefined;
            body?: false | (() => vue.VNodeChild) | undefined;
            tbody?: false | (() => vue.VNodeChild) | undefined;
            thead?: false | (() => vue.VNodeChild) | undefined;
            tfoot?: false | (() => vue.VNodeChild) | undefined;
            bottom?: false | (() => vue.VNodeChild) | undefined;
            'footer.prepend'?: false | (() => vue.VNodeChild) | undefined;
        } | undefined;
    } & {
        [x: `v-slot:item.${string}`]: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        "v-slot:default"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:item"?: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        "v-slot:loading"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:group-header"?: false | ((args_0: {
            index: number;
            item: GroupHeaderItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
            toggleGroup: (group: GroupHeaderItem) => void;
            isGroupOpen: (group: GroupHeaderItem) => boolean;
        }) => vue.VNodeChild) | undefined;
        "v-slot:no-data"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:expanded-row"?: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        "v-slot:item.data-table-select"?: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        "v-slot:item.data-table-expand"?: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        "v-slot:colgroup"?: false | ((args_0: InternalDataTableHeader) => vue.VNodeChild) | undefined;
        "v-slot:top"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:headers"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:body"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:tbody"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:thead"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:tfoot"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:bottom"?: false | (() => vue.VNodeChild) | undefined;
        "v-slot:footer.prepend"?: false | (() => vue.VNodeChild) | undefined;
    } & {
        "onUpdate:modelValue"?: ((value: any[]) => any) | undefined;
        "onUpdate:page"?: ((page: number) => any) | undefined;
        "onUpdate:itemsPerPage"?: ((page: number) => any) | undefined;
        "onUpdate:sortBy"?: ((sortBy: any) => any) | undefined;
        "onUpdate:groupBy"?: ((value: any) => any) | undefined;
        "onUpdate:expanded"?: ((options: any) => any) | undefined;
        "onClick:row"?: ((e: Event, value: {
            item: DataTableItem;
        }) => any) | undefined;
        "onUpdate:options"?: ((options: any) => any) | undefined;
    } & vue.ShallowUnwrapRef<{}> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<{
    style: vue.StyleValue;
    expanded: string[];
    tag: string;
    page: string | number;
    sticky: boolean;
    headers: DataTableHeader[] | DataTableHeader[][];
    noDataText: string;
    loadingText: string;
    itemsPerPageText: string;
    sortBy: SortItem[];
    pageText: string;
    items: any[];
    density: Density;
    modelValue: any[];
    itemTitle: SelectItemKey;
    itemValue: NonNullable<SelectItemKey>;
    itemChildren: SelectItemKey;
    itemProps: SelectItemKey;
    returnObject: boolean;
    hideNoData: boolean;
    hover: boolean;
    nextIcon: string;
    prevIcon: string;
    firstIcon: string;
    lastIcon: string;
    fixedHeader: boolean;
    fixedFooter: boolean;
    itemsPerPage: string | number;
    itemsLength: string | number;
    firstPageLabel: string;
    prevPageLabel: string;
    nextPageLabel: string;
    lastPageLabel: string;
    itemsPerPageOptions: {
        title: string;
        value: number;
    }[];
    showCurrentPage: boolean;
    multiSort: boolean;
    mustSort: boolean;
    groupBy: SortItem[];
    showSelect: boolean;
    sortAscIcon: IconValue;
    sortDescIcon: IconValue;
    expandOnClick: boolean;
    showExpand: boolean;
} & {
    search?: string | undefined;
    height?: string | number | undefined;
    width?: string | number | undefined;
    color?: string | undefined;
    loading?: string | boolean | undefined;
    class?: any;
    theme?: string | undefined;
    rowHeight?: number | undefined;
    'onClick:row'?: ((e: Event, value: {
        item: DataTableItem;
    }) => void) | undefined;
} & {
    $children?: vue.VNodeChild | (() => vue.VNodeChild) | {
        [x: `item.${string}`]: ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        default?: (() => vue.VNodeChild) | undefined;
        item?: ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        loading?: (() => vue.VNodeChild) | undefined;
        'group-header'?: ((args_0: {
            index: number;
            item: GroupHeaderItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
            toggleGroup: (group: GroupHeaderItem) => void;
            isGroupOpen: (group: GroupHeaderItem) => boolean;
        }) => vue.VNodeChild) | undefined;
        'no-data'?: (() => vue.VNodeChild) | undefined;
        'expanded-row'?: ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        'item.data-table-select'?: ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        'item.data-table-expand'?: ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        colgroup?: ((args_0: InternalDataTableHeader) => vue.VNodeChild) | undefined;
        top?: (() => vue.VNodeChild) | undefined;
        headers?: (() => vue.VNodeChild) | undefined;
        body?: (() => vue.VNodeChild) | undefined;
        tbody?: (() => vue.VNodeChild) | undefined;
        thead?: (() => vue.VNodeChild) | undefined;
        tfoot?: (() => vue.VNodeChild) | undefined;
        bottom?: (() => vue.VNodeChild) | undefined;
        'footer.prepend'?: (() => vue.VNodeChild) | undefined;
    };
    'v-slots'?: {
        [x: `item.${string}`]: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        default?: false | (() => vue.VNodeChild) | undefined;
        item?: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        loading?: false | (() => vue.VNodeChild) | undefined;
        'group-header'?: false | ((args_0: {
            index: number;
            item: GroupHeaderItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
            toggleGroup: (group: GroupHeaderItem) => void;
            isGroupOpen: (group: GroupHeaderItem) => boolean;
        }) => vue.VNodeChild) | undefined;
        'no-data'?: false | (() => vue.VNodeChild) | undefined;
        'expanded-row'?: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        'item.data-table-select'?: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        'item.data-table-expand'?: false | ((args_0: {
            index: number;
            item: DataTableItem;
            columns: InternalDataTableHeader[];
            isExpanded: (item: DataTableItem) => boolean;
            toggleExpand: (item: DataTableItem) => void;
            isSelected: (items: DataTableItem[]) => boolean;
            toggleSelect: (item: DataTableItem) => void;
        }) => vue.VNodeChild) | undefined;
        colgroup?: false | ((args_0: InternalDataTableHeader) => vue.VNodeChild) | undefined;
        top?: false | (() => vue.VNodeChild) | undefined;
        headers?: false | (() => vue.VNodeChild) | undefined;
        body?: false | (() => vue.VNodeChild) | undefined;
        tbody?: false | (() => vue.VNodeChild) | undefined;
        thead?: false | (() => vue.VNodeChild) | undefined;
        tfoot?: false | (() => vue.VNodeChild) | undefined;
        bottom?: false | (() => vue.VNodeChild) | undefined;
        'footer.prepend'?: false | (() => vue.VNodeChild) | undefined;
    } | undefined;
} & {
    [x: `v-slot:item.${string}`]: false | ((args_0: {
        index: number;
        item: DataTableItem;
        columns: InternalDataTableHeader[];
        isExpanded: (item: DataTableItem) => boolean;
        toggleExpand: (item: DataTableItem) => void;
        isSelected: (items: DataTableItem[]) => boolean;
        toggleSelect: (item: DataTableItem) => void;
    }) => vue.VNodeChild) | undefined;
    "v-slot:default"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:item"?: false | ((args_0: {
        index: number;
        item: DataTableItem;
        columns: InternalDataTableHeader[];
        isExpanded: (item: DataTableItem) => boolean;
        toggleExpand: (item: DataTableItem) => void;
        isSelected: (items: DataTableItem[]) => boolean;
        toggleSelect: (item: DataTableItem) => void;
    }) => vue.VNodeChild) | undefined;
    "v-slot:loading"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:group-header"?: false | ((args_0: {
        index: number;
        item: GroupHeaderItem;
        columns: InternalDataTableHeader[];
        isExpanded: (item: DataTableItem) => boolean;
        toggleExpand: (item: DataTableItem) => void;
        isSelected: (items: DataTableItem[]) => boolean;
        toggleSelect: (item: DataTableItem) => void;
        toggleGroup: (group: GroupHeaderItem) => void;
        isGroupOpen: (group: GroupHeaderItem) => boolean;
    }) => vue.VNodeChild) | undefined;
    "v-slot:no-data"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:expanded-row"?: false | ((args_0: {
        index: number;
        item: DataTableItem;
        columns: InternalDataTableHeader[];
        isExpanded: (item: DataTableItem) => boolean;
        toggleExpand: (item: DataTableItem) => void;
        isSelected: (items: DataTableItem[]) => boolean;
        toggleSelect: (item: DataTableItem) => void;
    }) => vue.VNodeChild) | undefined;
    "v-slot:item.data-table-select"?: false | ((args_0: {
        index: number;
        item: DataTableItem;
        columns: InternalDataTableHeader[];
        isExpanded: (item: DataTableItem) => boolean;
        toggleExpand: (item: DataTableItem) => void;
        isSelected: (items: DataTableItem[]) => boolean;
        toggleSelect: (item: DataTableItem) => void;
    }) => vue.VNodeChild) | undefined;
    "v-slot:item.data-table-expand"?: false | ((args_0: {
        index: number;
        item: DataTableItem;
        columns: InternalDataTableHeader[];
        isExpanded: (item: DataTableItem) => boolean;
        toggleExpand: (item: DataTableItem) => void;
        isSelected: (items: DataTableItem[]) => boolean;
        toggleSelect: (item: DataTableItem) => void;
    }) => vue.VNodeChild) | undefined;
    "v-slot:colgroup"?: false | ((args_0: InternalDataTableHeader) => vue.VNodeChild) | undefined;
    "v-slot:top"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:headers"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:body"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:tbody"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:thead"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:tfoot"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:bottom"?: false | (() => vue.VNodeChild) | undefined;
    "v-slot:footer.prepend"?: false | (() => vue.VNodeChild) | undefined;
} & {
    "onUpdate:modelValue"?: ((value: any[]) => any) | undefined;
    "onUpdate:page"?: ((page: number) => any) | undefined;
    "onUpdate:itemsPerPage"?: ((page: number) => any) | undefined;
    "onUpdate:sortBy"?: ((sortBy: any) => any) | undefined;
    "onUpdate:groupBy"?: ((value: any) => any) | undefined;
    "onUpdate:expanded"?: ((options: any) => any) | undefined;
    "onClick:row"?: ((e: Event, value: {
        item: DataTableItem;
    }) => any) | undefined;
    "onUpdate:options"?: ((options: any) => any) | undefined;
}, void, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {
    'update:modelValue': (value: any[]) => true;
    'update:page': (page: number) => true;
    'update:itemsPerPage': (page: number) => true;
    'update:sortBy': (sortBy: any) => true;
    'update:options': (options: any) => true;
    'update:expanded': (options: any) => true;
    'update:groupBy': (value: any) => true;
    'click:row': (e: Event, value: {
        item: DataTableItem;
    }) => true;
}, string, {
    style: vue.StyleValue;
    expanded: string[];
    tag: string;
    page: string | number;
    sticky: boolean;
    headers: DataTableHeader[] | DataTableHeader[][];
    noDataText: string;
    loadingText: string;
    itemsPerPageText: string;
    sortBy: SortItem[];
    pageText: string;
    items: any[];
    density: Density;
    modelValue: any[];
    itemTitle: SelectItemKey;
    itemValue: NonNullable<SelectItemKey>;
    itemChildren: SelectItemKey;
    itemProps: SelectItemKey;
    returnObject: boolean;
    hideNoData: boolean;
    hover: boolean;
    nextIcon: string;
    prevIcon: string;
    firstIcon: string;
    lastIcon: string;
    fixedHeader: boolean;
    fixedFooter: boolean;
    itemsPerPage: string | number;
    firstPageLabel: string;
    prevPageLabel: string;
    nextPageLabel: string;
    lastPageLabel: string;
    itemsPerPageOptions: {
        title: string;
        value: number;
    }[];
    showCurrentPage: boolean;
    multiSort: boolean;
    mustSort: boolean;
    groupBy: SortItem[];
    showSelect: boolean;
    sortAscIcon: IconValue;
    sortDescIcon: IconValue;
    expandOnClick: boolean;
    showExpand: boolean;
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & FilterPropsOptions<{
    prevIcon: {
        type: StringConstructor;
        default: string;
    };
    nextIcon: {
        type: StringConstructor;
        default: string;
    };
    firstIcon: {
        type: StringConstructor;
        default: string;
    };
    lastIcon: {
        type: StringConstructor;
        default: string;
    };
    itemsPerPageText: {
        type: StringConstructor;
        default: string;
    };
    pageText: {
        type: StringConstructor;
        default: string;
    };
    firstPageLabel: {
        type: StringConstructor;
        default: string;
    };
    prevPageLabel: {
        type: StringConstructor;
        default: string;
    };
    nextPageLabel: {
        type: StringConstructor;
        default: string;
    };
    lastPageLabel: {
        type: StringConstructor;
        default: string;
    };
    itemsPerPageOptions: {
        type: vue.PropType<{
            title: string;
            value: number;
        }[]>;
        default: () => {
            value: number;
            title: string;
        }[];
    };
    showCurrentPage: BooleanConstructor;
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    density: {
        type: vue.PropType<Density>;
        default: string;
        validator: (v: any) => boolean;
    };
    class: vue.PropType<any>;
    style: {
        type: vue.PropType<vue.StyleValue>;
        default: null;
    };
    fixedHeader: BooleanConstructor;
    fixedFooter: BooleanConstructor;
    height: (StringConstructor | NumberConstructor)[];
    hover: BooleanConstructor;
    loading: (StringConstructor | BooleanConstructor)[];
    color: StringConstructor;
    sticky: BooleanConstructor;
    multiSort: BooleanConstructor;
    sortAscIcon: {
        type: vue.PropType<IconValue>;
        default: string;
    };
    sortDescIcon: {
        type: vue.PropType<IconValue>;
        default: string;
    };
    sortBy: {
        type: vue.PropType<SortItem[]>;
        default: () => never[];
    };
    mustSort: BooleanConstructor;
    showSelect: BooleanConstructor;
    modelValue: {
        type: vue.PropType<any[]>;
        default: () => never[];
    };
    items: {
        type: vue.PropType<any[]>;
        default: () => never[];
    };
    itemTitle: {
        type: vue.PropType<SelectItemKey>;
        default: string;
    };
    itemValue: Omit<{
        type: vue.PropType<SelectItemKey>;
        default: string;
    }, "type" | "default"> & {
        type: vue.PropType<NonNullable<SelectItemKey>>;
        default: NonNullable<SelectItemKey>;
    };
    itemChildren: {
        type: vue.PropType<SelectItemKey>;
        default: string;
    };
    itemProps: {
        type: vue.PropType<SelectItemKey>;
        default: string;
    };
    returnObject: BooleanConstructor;
    headers: {
        type: vue.PropType<DataTableHeader[] | DataTableHeader[][]>;
        default: () => never[];
    };
    groupBy: {
        type: vue.PropType<SortItem[]>;
        default: () => never[];
    };
    expandOnClick: BooleanConstructor;
    showExpand: BooleanConstructor;
    expanded: {
        type: vue.PropType<string[]>;
        default: () => never[];
    };
    width: (StringConstructor | NumberConstructor)[];
    search: StringConstructor;
    loadingText: {
        type: StringConstructor;
        default: string;
    };
    hideNoData: BooleanConstructor;
    noDataText: {
        type: StringConstructor;
        default: string;
    };
    rowHeight: NumberConstructor;
    'onClick:row': vue.PropType<(e: Event, value: {
        item: DataTableItem;
    }) => void>;
    page: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    itemsPerPage: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    itemsLength: {
        type: (StringConstructor | NumberConstructor)[];
        required: true;
    };
}, vue.ExtractPropTypes<{
    prevIcon: {
        type: StringConstructor;
        default: string;
    };
    nextIcon: {
        type: StringConstructor;
        default: string;
    };
    firstIcon: {
        type: StringConstructor;
        default: string;
    };
    lastIcon: {
        type: StringConstructor;
        default: string;
    };
    itemsPerPageText: {
        type: StringConstructor;
        default: string;
    };
    pageText: {
        type: StringConstructor;
        default: string;
    };
    firstPageLabel: {
        type: StringConstructor;
        default: string;
    };
    prevPageLabel: {
        type: StringConstructor;
        default: string;
    };
    nextPageLabel: {
        type: StringConstructor;
        default: string;
    };
    lastPageLabel: {
        type: StringConstructor;
        default: string;
    };
    itemsPerPageOptions: {
        type: vue.PropType<{
            title: string;
            value: number;
        }[]>;
        default: () => {
            value: number;
            title: string;
        }[];
    };
    showCurrentPage: BooleanConstructor;
    theme: StringConstructor;
    tag: {
        type: StringConstructor;
        default: string;
    };
    density: {
        type: vue.PropType<Density>;
        default: string;
        validator: (v: any) => boolean;
    };
    class: vue.PropType<any>;
    style: {
        type: vue.PropType<vue.StyleValue>;
        default: null;
    };
    fixedHeader: BooleanConstructor;
    fixedFooter: BooleanConstructor;
    height: (StringConstructor | NumberConstructor)[];
    hover: BooleanConstructor;
    loading: (StringConstructor | BooleanConstructor)[];
    color: StringConstructor;
    sticky: BooleanConstructor;
    multiSort: BooleanConstructor;
    sortAscIcon: {
        type: vue.PropType<IconValue>;
        default: string;
    };
    sortDescIcon: {
        type: vue.PropType<IconValue>;
        default: string;
    };
    sortBy: {
        type: vue.PropType<SortItem[]>;
        default: () => never[];
    };
    mustSort: BooleanConstructor;
    showSelect: BooleanConstructor;
    modelValue: {
        type: vue.PropType<any[]>;
        default: () => never[];
    };
    items: {
        type: vue.PropType<any[]>;
        default: () => never[];
    };
    itemTitle: {
        type: vue.PropType<SelectItemKey>;
        default: string;
    };
    itemValue: Omit<{
        type: vue.PropType<SelectItemKey>;
        default: string;
    }, "type" | "default"> & {
        type: vue.PropType<NonNullable<SelectItemKey>>;
        default: NonNullable<SelectItemKey>;
    };
    itemChildren: {
        type: vue.PropType<SelectItemKey>;
        default: string;
    };
    itemProps: {
        type: vue.PropType<SelectItemKey>;
        default: string;
    };
    returnObject: BooleanConstructor;
    headers: {
        type: vue.PropType<DataTableHeader[] | DataTableHeader[][]>;
        default: () => never[];
    };
    groupBy: {
        type: vue.PropType<SortItem[]>;
        default: () => never[];
    };
    expandOnClick: BooleanConstructor;
    showExpand: BooleanConstructor;
    expanded: {
        type: vue.PropType<string[]>;
        default: () => never[];
    };
    width: (StringConstructor | NumberConstructor)[];
    search: StringConstructor;
    loadingText: {
        type: StringConstructor;
        default: string;
    };
    hideNoData: BooleanConstructor;
    noDataText: {
        type: StringConstructor;
        default: string;
    };
    rowHeight: NumberConstructor;
    'onClick:row': vue.PropType<(e: Event, value: {
        item: DataTableItem;
    }) => void>;
    page: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    itemsPerPage: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    itemsLength: {
        type: (StringConstructor | NumberConstructor)[];
        required: true;
    };
}>>;
type VDataTableServer = InstanceType<typeof VDataTableServer>;

declare const VDataTableFooter: {
    new (...args: any[]): {
        $: vue.ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            itemsPerPageText: string;
            pageText: string;
            nextIcon: string;
            prevIcon: string;
            firstIcon: string;
            lastIcon: string;
            firstPageLabel: string;
            prevPageLabel: string;
            nextPageLabel: string;
            lastPageLabel: string;
            itemsPerPageOptions: {
                title: string;
                value: number;
            }[];
            showCurrentPage: boolean;
        }> & Omit<{
            itemsPerPageText: string;
            pageText: string;
            nextIcon: string;
            prevIcon: string;
            firstIcon: string;
            lastIcon: string;
            firstPageLabel: string;
            prevPageLabel: string;
            nextPageLabel: string;
            lastPageLabel: string;
            itemsPerPageOptions: {
                title: string;
                value: number;
            }[];
            showCurrentPage: boolean;
        } & {} & {
            $children?: {} | vue.VNodeChild | {
                prepend?: (() => vue.VNodeChild) | undefined;
            };
            'v-slots'?: {
                prepend?: false | (() => vue.VNodeChild) | undefined;
            } | undefined;
        } & {
            "v-slot:prepend"?: false | (() => vue.VNodeChild) | undefined;
        } & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, "itemsPerPageText" | "pageText" | "nextIcon" | "prevIcon" | "firstIcon" | "lastIcon" | "firstPageLabel" | "prevPageLabel" | "nextPageLabel" | "lastPageLabel" | "itemsPerPageOptions" | "showCurrentPage">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: vue.Slot | undefined;
        }>;
        $root: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $parent: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null;
        $emit: (event: string, ...args: any[]) => void;
        $el: any;
        $options: vue.ComponentOptionsBase<{
            itemsPerPageText: string;
            pageText: string;
            nextIcon: string;
            prevIcon: string;
            firstIcon: string;
            lastIcon: string;
            firstPageLabel: string;
            prevPageLabel: string;
            nextPageLabel: string;
            lastPageLabel: string;
            itemsPerPageOptions: {
                title: string;
                value: number;
            }[];
            showCurrentPage: boolean;
        } & {} & {
            $children?: {} | vue.VNodeChild | {
                prepend?: (() => vue.VNodeChild) | undefined;
            };
            'v-slots'?: {
                prepend?: false | (() => vue.VNodeChild) | undefined;
            } | undefined;
        } & {
            "v-slot:prepend"?: false | (() => vue.VNodeChild) | undefined;
        }, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, Record<string, any>, string, {
            itemsPerPageText: string;
            pageText: string;
            nextIcon: string;
            prevIcon: string;
            firstIcon: string;
            lastIcon: string;
            firstPageLabel: string;
            prevPageLabel: string;
            nextPageLabel: string;
            lastPageLabel: string;
            itemsPerPageOptions: {
                title: string;
                value: number;
            }[];
            showCurrentPage: boolean;
        }, {}, string> & {
            beforeCreate?: ((() => void) | (() => void)[]) | undefined;
            created?: ((() => void) | (() => void)[]) | undefined;
            beforeMount?: ((() => void) | (() => void)[]) | undefined;
            mounted?: ((() => void) | (() => void)[]) | undefined;
            beforeUpdate?: ((() => void) | (() => void)[]) | undefined;
            updated?: ((() => void) | (() => void)[]) | undefined;
            activated?: ((() => void) | (() => void)[]) | undefined;
            deactivated?: ((() => void) | (() => void)[]) | undefined;
            beforeDestroy?: ((() => void) | (() => void)[]) | undefined;
            beforeUnmount?: ((() => void) | (() => void)[]) | undefined;
            destroyed?: ((() => void) | (() => void)[]) | undefined;
            unmounted?: ((() => void) | (() => void)[]) | undefined;
            renderTracked?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            renderTriggered?: (((e: vue.DebuggerEvent) => void) | ((e: vue.DebuggerEvent) => void)[]) | undefined;
            errorCaptured?: (((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void) | ((err: unknown, instance: vue.ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, vue.ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}, {}, string>, {}> | null, info: string) => boolean | void)[]) | undefined;
        };
        $forceUpdate: () => void;
        $nextTick: typeof vue.nextTick;
        $watch<T extends string | ((...args: any) => any)>(source: T, cb: T extends (...args: any) => infer R ? (args_0: R, args_1: R) => any : (...args: any) => any, options?: vue.WatchOptions<boolean> | undefined): vue.WatchStopHandle;
    } & {
        itemsPerPageText: string;
        pageText: string;
        nextIcon: string;
        prevIcon: string;
        firstIcon: string;
        lastIcon: string;
        firstPageLabel: string;
        prevPageLabel: string;
        nextPageLabel: string;
        lastPageLabel: string;
        itemsPerPageOptions: {
            title: string;
            value: number;
        }[];
        showCurrentPage: boolean;
    } & {} & {
        $children?: {} | vue.VNodeChild | {
            prepend?: (() => vue.VNodeChild) | undefined;
        };
        'v-slots'?: {
            prepend?: false | (() => vue.VNodeChild) | undefined;
        } | undefined;
    } & {
        "v-slot:prepend"?: false | (() => vue.VNodeChild) | undefined;
    } & vue.ShallowUnwrapRef<() => JSX.Element> & {} & vue.ComponentCustomProperties & {};
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & vue.ComponentOptionsBase<{
    itemsPerPageText: string;
    pageText: string;
    nextIcon: string;
    prevIcon: string;
    firstIcon: string;
    lastIcon: string;
    firstPageLabel: string;
    prevPageLabel: string;
    nextPageLabel: string;
    lastPageLabel: string;
    itemsPerPageOptions: {
        title: string;
        value: number;
    }[];
    showCurrentPage: boolean;
} & {} & {
    $children?: {} | vue.VNodeChild | {
        prepend?: (() => vue.VNodeChild) | undefined;
    };
    'v-slots'?: {
        prepend?: false | (() => vue.VNodeChild) | undefined;
    } | undefined;
} & {
    "v-slot:prepend"?: false | (() => vue.VNodeChild) | undefined;
}, () => JSX.Element, unknown, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, Record<string, any>, string, {
    itemsPerPageText: string;
    pageText: string;
    nextIcon: string;
    prevIcon: string;
    firstIcon: string;
    lastIcon: string;
    firstPageLabel: string;
    prevPageLabel: string;
    nextPageLabel: string;
    lastPageLabel: string;
    itemsPerPageOptions: {
        title: string;
        value: number;
    }[];
    showCurrentPage: boolean;
}, {}, string> & vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps & FilterPropsOptions<{
    prevIcon: {
        type: StringConstructor;
        default: string;
    };
    nextIcon: {
        type: StringConstructor;
        default: string;
    };
    firstIcon: {
        type: StringConstructor;
        default: string;
    };
    lastIcon: {
        type: StringConstructor;
        default: string;
    };
    itemsPerPageText: {
        type: StringConstructor;
        default: string;
    };
    pageText: {
        type: StringConstructor;
        default: string;
    };
    firstPageLabel: {
        type: StringConstructor;
        default: string;
    };
    prevPageLabel: {
        type: StringConstructor;
        default: string;
    };
    nextPageLabel: {
        type: StringConstructor;
        default: string;
    };
    lastPageLabel: {
        type: StringConstructor;
        default: string;
    };
    itemsPerPageOptions: {
        type: PropType<{
            title: string;
            value: number;
        }[]>;
        default: () => {
            value: number;
            title: string;
        }[];
    };
    showCurrentPage: BooleanConstructor;
}, vue.ExtractPropTypes<{
    prevIcon: {
        type: StringConstructor;
        default: string;
    };
    nextIcon: {
        type: StringConstructor;
        default: string;
    };
    firstIcon: {
        type: StringConstructor;
        default: string;
    };
    lastIcon: {
        type: StringConstructor;
        default: string;
    };
    itemsPerPageText: {
        type: StringConstructor;
        default: string;
    };
    pageText: {
        type: StringConstructor;
        default: string;
    };
    firstPageLabel: {
        type: StringConstructor;
        default: string;
    };
    prevPageLabel: {
        type: StringConstructor;
        default: string;
    };
    nextPageLabel: {
        type: StringConstructor;
        default: string;
    };
    lastPageLabel: {
        type: StringConstructor;
        default: string;
    };
    itemsPerPageOptions: {
        type: PropType<{
            title: string;
            value: number;
        }[]>;
        default: () => {
            value: number;
            title: string;
        }[];
    };
    showCurrentPage: BooleanConstructor;
}>>;

export { VDataTable, VDataTableFooter, VDataTableRow, VDataTableRows, VDataTableServer, VDataTableVirtual };
